package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.36.0 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.36.0) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@$"`0`````````````#``@````!```2H````#0``*'\(```)P`T`"``
M"@`H`!\`'@````8````T````-````#0```%````!0`````0````$`````P``
M`70```%T```!=````!<````7````!`````%P```#```!N````;@```&X````
M&````!@````$````"'````````'0```!T````=`````8````&`````0````(
M`````0``````````````````F5@``)E8````!0`!```````!``"96``!F5@`
M`9E8```"-```!H@````&``$```````(```'H```!Z````>@```$(```!"```
M``0````$````!````8P```&,```!C````"P````L````!`````1D=.50``"3
M0```DT```)-`````Y````.0````$````!```````````````````````````
M```````````````$+W5S<B]L:6)E>&5C+VQD+F5L9E]S;P``````!P````0`
M```!3F5T0E-$```UI.D`````!`````0````#4&%8``````````,``@```P``
M`````````````0`````2`("P```````````````````````"&;`````!````
M'`````$```*/`````0```ID````!```"U0````$```+[````#P``!(<````,
M```28`````T``%.`````!````O`````%```,B`````8```88````"@``!-``
M```+````$'```#4``9=@````%0`````````#``&9P````!$``!%8````$@``
M`#`````3````"'````$````!<```!0````)P```&`````'````H````L<```
M$0```&=P```2````'G```!,````C;___^P@`````````````````````````
M``````````````````````````````````````````````!A````9P``````
M````````#0```%X``````````````$````!=````.@````````!&````````
M`&8````T````'P````````!2````%P````(```!4````!@````<````X````
M`````!T`````````60```!$````O````)P`````````B````)````$<`````
M`````````!,````A````*P```#<`````````-0```$\```!"````+`````\`
M``!*`````````&,````8`````````%\`````````(P```"T````6````40``
M`&4````E`````````"D`````````6````$@````S````'@``````````````
M7````$0`````````80```"@````R````````````````````"````#\`````
M````&0````X````V`````````#T````<````````````````````%0``````
M```^````&P```"8`````````(```````````````````````````````````
M`````````````````````````````````$X``````````````&0````*````
M`````$4``````````P````D````````````````````2````8@``````````
M`````````````````````````#$```!:````+@`````````J````00``````
M````````%``````````:`````````#P`````````30```#``````````.P``
M``P````````````````````Y`````````````````````````%,````0````
M0P`````````%`````````%<```!6````50```&`````$`````````$D```!,
M````"P```$L`````````4```````````````````````````````````````
M``!;````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````!)@``````,```L```0&```=@`````@2```,`````0````$`````
M$P#_\0```Y,``"3X````3!(```P```1'```ST````+@2```,```$6``!FX@`
M````$```%P```%```%.`````&!(```X```0P```@&````#`2```,```$)```
M($@```%L$@``#```!!<``":(```*,!(```P```!D```````````6```````!
MZ@`!FX@````$$0``&````^0``$=H```"/!(```P```1?``&9<``````0```5
M````$@`!F;``````$0``%@``!#T``9F@````!!$``!4```13``&?X``````1
M```9```$<P``$J`````D$@``#````_D``"&X```"A!(```P```/O``!)J```
M`>P2```,```$9@`!FX@`````$```&````W4``!RX````5!(```P```-P``!-
M$````JP2```,```$<@``$J`````D$@``#````\```!V(```"C!(```P```.N
M```E2````4`2```,```#S0``)$````"T$@``#```!'H``!*@`````!````P`
M``--``&;D`````01```9```$@0`!FX@`````$```&````]L``$;@````A!(`
M``P```-:``&9<`````01```5```#W@``$F`````8$@``"P```WT``#"X```#
M%!(```P```,E``!38``````2````````UP``4U``````$@```````=```%-`
M`````!(```````#>```````````1````````XP``4S``````$@```````/(`
M`%,@`````!(```````-E``!3$``````2````````^0``4P``````$@``````
M`0```%+P`````!(```````-```!2X``````2```````!"```4M``````$@``
M`````0T``%+``````!(```````#.``!2L``````2```````"Y0``4J``````
M$@```````+T``````````!(```````$3``!2D``````2```````"O0``````
M````(@```````2H``%*``````!(```````$Q``!2<``````2```````!.```
M4F``````$@```````+(``%)0`````!(```````%)``!20``````2```````!
M3P``4C``````$@```````5L``%(@`````!(```````"D``!2$``````2````
M```"[```4@``````$@```````)$``````````!(```````%C``!1\``````2
M```````!;@``4>``````$@```````8,``%'0`````!(```````""``!1P```
M```2```````!CP``4;``````$@```````90``%&@`````!(```````&B``!1
MD``````2```````!L@``````````$0```````<0``%&``````!(```````'7
M``!1<``````2```````#%```46``````$@```````=X``%%0`````!(`````
M``'R``!10``````2```````#'@``43``````$@```````'<``%$@`````!(`
M``````,&``!1$``````2```````!^P``40``````$@```````J<`````````
M`"(```````()```````````1```````"%@``4/``````$@```````%8``%#@
M`````!(```````(G``!0T``````2```````#.```4,``````$@```````BX`
M`%"P`````!(```````(T``!0H``````2````````1@``4)``````$@``````
M`CT``%"``````!(```````)'``!0<``````2````````-P``4&``````$@``
M`````"<``````````!(```````!+``!04``````2```````#,0``4$``````
M$@```````DX``%`P`````!(```````)6``!0(``````2```````"70``4!``
M````$@```````F,``%```````!(```````)J``!/\``````2```````"<```
M````````(@```````G\``$_@`````!(```````*'``!/T``````2```````"
M+P``3\``````$@````!?1%E.04U)0U],24Y+24Y'`%]?4DQ$7TU!4`!L:6)P
M97)L+G-O`&)O;W1?1'EN84QO861E<@!P97)L7V-O;G-T<G5C=`!P97)L7V9R
M964`7V9I;FD`<&5R;%]D97-T<G5C=`!03%]C=7)R96YT7V-O;G1E>'0`<&5R
M;%]A;&QO8P!097)L7W-Y<U]I;FET,P!097)L7V%T9F]R:U]U;FQO8VL`4&5R
M;%]S>7-?=&5R;0!P97)L7W!A<G-E`%!E<FQ?871F;W)K7VQO8VL`<&5R;%]R
M=6X`<W1R8VUP`%]?<T8`7U]T;'-?9V5T7V%D9'(`<W1R;&5N`&=E='5I9`!S
M<')I;G1F`&]P96X`;'-E96L`4&5R;%]C<F]A:U]M96UO<GE?=W)A<`!G971P
M:60`86-C97-S`%!E<FQ?;F5W6%-?9FQA9W,`;6MD:7(`4&5R;%]M9U]S970`
M7U]E<G)N;P!097)L7VYE=UA3`%!E<FQ?8W)O86M?;F]C;VYT97AT`%!E<FQ?
M9V5T7W-V`')E860`7U]S<')I;G1F7V-H:P!097)L7V=V7V9E=&-H<'8`7U]S
M=&%C:U]C:&M?9W5A<F0`4&5R;%]S869E<WES;6%L;&]C`&UE;7-E=`!?7V]P
M96YD:7(S,`!E;G9I<F]N`&-L;W-E9&ER`%!E<FQ?<W9?<V5T<'8`4$Q?9&]?
M=6YD=6UP`%]?<W1A8VM?8VAK7V9A:6P`;65M8W!Y`%]E>&ET`%]?<W1A=#4P
M`%]?;'-T870U,`!U;FQI;FL`<W1R;F-M<`!S=')C:'(`8VQO<V4`<W1R<W1R
M`')M9&ER`%]?8WAA7V9I;F%L:7IE`&UE;6UO=F4`<F5A;&QO8P!L:6)M+G-O
M+C``;&EB8W)Y<'0N<V\N,0!?7W)E9VES=&5R7V9R86UE7VEN9F\`7U]D97)E
M9VES=&5R7V9R86UE7VEN9F\`;&EB<'1H<F5A9"YS;RXQ`'-T<F1U<`!P=&AR
M96%D7V%T9F]R:P!L:6)C+G-O+C$R`%]?<W1R;F-P>5]C:&L`7U]S>7-C86QL
M`'-T<G1O:P!?7W)E861D:7(S,`!A=&5X:70`9G!R:6YT9@!?7V=E='!W=6ED
M-3``7U]P<U]S=')I;F=S`%]?<')O9VYA;64`7VQI8F-?:6YI=`!M86EN`'AS
M7VEN:70`6%-?26YT97)N86QS7U!!4E]"3T]4`&=E=%]U<V5R;F%M95]F<F]M
M7V=E='!W=6ED`'!A<E]S971U<%]L:6)P871H`'!A<E]F:6YD<')O9P!P87)?
M96YV7V-L96%N`'-H85]I;FET`'-H85]U<&1A=&4`<VAA7V9I;F%L`'!A<E]I
M;FET7V5N=@!P87)?8W5R<F5N=%]E>&5C`'!A<E]M:W1M<&1I<@!P87)?9&ER
M;F%M90!P87)?8F%S96YA;64`;7E?<&%R7W!L`'!A<E]C;&5A;G5P`%]E;F0`
M7V5D871A`%]F9&%T80!?7V)S<U]S=&%R=`!?7W-T87)T`%]F=&5X=`!?9F)S
M<P`O=7-R+W!K9R]L:6(O<&5R;#4O-2XS-BXP+VUI<',V-&5B+6YE=&)S9"UT
M:')E860M;75L=&DO0T]213HO=7-R+W!K9R]L:6(``````````````9EP````
M`P`!F8`````#``&9H`````,``9N````+)@`!FX0```LG````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````9[W_X/^_`!C_O``(/!P``B><!U`#
MF>`ACYF`0`01#G@`````W[\`&-^\``AGO0`@`^``"`````````````````.`
M>"4\'``")YP'$`.9X"$`H"`ECYF`&`#@*"40```B````````````````````
M`">]_^#_O``0/!P``@.9X"$GG`;@_[```(^"@!R/D(`<_[\`&`("&"L08``-
M_[$`"``0B"<"(H@A`!&(@B8Q``$`$8B``A&((8X9`````````R#X"280``16
M$?_]CAD``-^_`!C?O``0W[$`"-^P```#X``()[T`(">]_]#_O``@/!P``@.9
MX"'_OP`H_[,`&/^R`!#_L0`(_[```!"@`%4GG`9HC*(```"@D"6/DX`@C$,`
M`(RE``B/AH`DKF4``!!@`$>LT@``CX:`*"0%`"^LPP``C$(``(!#```08``'
M`````!1E__PD0@`!K,(``(!#```48/_[`````!"```./F8&H`R#X"0````"/
MF8#8`R#X"8^0@!R/@H`<`@(8*Q!@``Z/A(`L`!"()P(BB"$`$8B")C$``0`1
MB(`"$8@ACAD````````#(/@))A``!%81__V.&0``CX2`+(^9@:B/D(`<`R#X
M"22$$M"/@H`<`@(8*Q!@``V/F8&H`!"()P(BB"$`$8B")C$``0`1B(`"$8@A
MCAD```,@^`DF$``$5C#__8X9``"/F8&H`R#X"8^$@#"/F8`T`R#X"0````".
M1``$CYF`.(YF```#(/@)CD4``(^9@<P#(/@)`$`@)8^"@#R/@X`H)$*;F!``
M_\.L8@``CX:`+(^9@50D!``$)`<`$R3&4\`#(/@))`4``H^9@8@#(/@))`0`
M`0`````GO?^P_[P`0#P<``(#F>`A_[\`2/^V`#C_M0`P_[0`*/^S`"#_L@`8
M_[$`$/^P``@0@`!%)YP$P(^"@"",50``4J``'```@"6`@@``$$``!```D"4D
M`P`]5$,`(P"`D"6.L```$@``$P"@H"4`@)@E`J"()206`#V/F8&L``````(`
M("4"0#`E`R#X"0)@*"440``$`A(8(8!B``!05@`:`C6((R8Q``2.,```%@#_
M](^9@:S?OP!(`@`0)=^\`$#?M@`XW[4`,-^T`"C?LP`@W[(`&-^Q`!#?L``(
M`^``"">]`%``````)E(``8)"``!00/_;`D20(U1#__PF4@`!$`#_UP)$D",`
M$8B#KI$``-^_`$@F4@`!`A*`(0(`$"7?O`!`W[8`.-^U`##?M``HW[,`(-^R
M`!C?L0`0W[``"`/@``@GO0!0$`#_V@``@"4GO?^P_[P`0#P<``(#F>`A)YP#
M</^T`#B/E(%(_[,`,/^R`"C_L0`@_[``&/^_`$B.@@``CY"`+(^3@"``@)`E
M)[$`""80%/"OH@`,`B`H)0(`R"4#(/@)`D`@)1!``!*/HP`(CF(````#&(``
M0Q`AC$,`!!!@__6L0P```````"1"``2,0P`$%&#__:Q#```"("@E`@#()0,@
M^`D"0"`E%$#_\(^C``B/HP`,CH(``!1B``G?OP!(W[P`0-^T`#C?LP`PW[(`
M*-^Q`"#?L``8`^``"">]`%"/F8%X`R#X"0``````````)[W^\/^\`/@\'``"
M`YG@(2><`HC_L`"XCY"!2/^_`0C_O@$`_[<`\/^V`.C_M0#@_[0`V/^S`-#_
ML@#(_[$`P(X"``"OH@"L$(``!`````"`@@``%$``$@"`B"6/HP"LC@(``!1B
M`%[?OP$(W[X!`-^\`/C?MP#PW[8`Z-^U`.#?M`#8W[,`T-^R`,C?L0#`W[``
MN`/@``@GO0$0`````(^9@5@#(/@)`````!!`_^L`0)@ECY2`+(^5@"R/EH`L
MCY>`+">B`!`FE%/8)K53Z*^B``PFUA<HCYF`P`,@^`D"8"`E$$``,H^9@,0D
M4@`-`H`H)0,@^`D"0"`E$$#_]X^9@,"/F8#$)N53X`,@^`D"0"`E$$#_\8^9
M@,"/F8#4`R#X"0(@("6/F8#4`D`@)0,@^`D`0/`ECYF`R`/"$"$#(/@))$0`
M`H^9@.`"H"@E`$`@)0)`."4"(#`E`R#X"0!`\"6/I0`,CYF!C`,@^`D#P"`E
M)`/__Q!#``6/H@`8)`-``#!"\`!00P`1`L#()8^9@9@#(/@)`\`@)8^9@:0#
M(/@)`\`@)1``_\R/F8#`CYF!7`,@^`D"8"`ECYF!O`,@^`D"("`E$`#_I```
M```#(/@)`\`@)1``__&/F8&DCYF!>`,@^`D``````````">]_Z#_O`!0/!P`
M`O^_`%C_M``P_[(`(/^Q`!C_L``0_[<`2/^V`$#_M0`X_[,`*`.9X"$GG`"8
M@*(``(^2@4B/F8#4.$(`/8Y#```L0@`!`**`(0"`B"4"`"`EKZ,`#`,@^`D`
M````CYF`+">E``@"("`E)SD4\`,@^`D`0*`E$$``78^9@-0`0"`E`R#X"0!`
MF"4`5!`K4$``2R80``&/LP`(CY6`(``3L(""(@``$$``@20#`#U00P`*```@
M)1````,"("`E4$,`!@"1(",DA``!@((``!1`__L``````)$@(XZS``"/F8#(
M)I0``@,@^`D"A"`A`G:8(1!``'.N8@``CZ,`"(ZB``"")0````,8@`!#$"&,
M0P``)C$``1"@``Z@90``)`(`/5"B``PD!``]$```!"0%`#T`````$$4`!R0$
M`#TF,0`!@B+__R1C``$40/_ZH&(``"0$`#TD8@`!H&0``"80``&"`___)$(`
M`11@__R@0___```0)8^D``R.0P``%(,`4M^_`%C?O`!0W[<`2-^V`$#?M0`X
MW[0`,-^S`"C?L@`@W[$`&-^P`!`#X``()[T`8``````F$``!`````(("__\F
M<P`!$$#_ZJ)B__\F$``!@@+__R9S``$40/_VHF+__Q``_^0``!`E`````(^5
M@"".MP``CN(``!!``"X"X!`E$````P``*"4``````F`H)21"``2,0P``%&#_
M_"2S``$DI0`#``4H@(^"@#R,0Y_0%&``%H^9@<B/F8#()`,``0"@("4#(/@)
MK$.?T!!``!R/F8'$`!.P@`+`,"4"X"@E`R#X"0!`("4`0!@EKJ(``"9B``$`
M`A"``&(8(:Q@```0`/^'K[,`"``````#(/@)`N`@)0!`&"400``)KJ(``!``
M__,`$["``````!``_XH``"`E)`4`"!``_]L``)@E$`#_K"0"__^/F8%X`R#X
M"0`````GO?]`_[P`L#P<``(#F>`A)YS]N/^P`*"/D(%(_[$`J/^_`+B/F8&4
MC@(```.@*"4`@(@EKZ(`G`,@^`D`````%$``&8^C``@D!$``,&/P`!!D``TT
M!*``$&0`#8^9@0B/I`"<C@,``!2#`!'?OP"XW[P`L-^Q`*C?L`"@`^``"">]
M`,``````CYF!"``````D!0`"`R#X"0(@("40`/_P+$(``0`````0`/_M```0
M)8^9@7@#(/@)```````````GO?_P_[P``#P<``(#F>`A)YS\^(^9@-#_OP`(
M`R#X"2>$@="/AX!<CX6`+(^&@:"/F8$LC$0``"3GDR@#(/@))*53\-^_``C?
MO````^``"">]`!``````)[W_X/^\`!`\'``"`YG@(2><_*"/F8#0_[\`&`,@
M^`DGA('0C$0``(^9@&`#(/@)KZ(`#(^B``R/B(`LCX6`+(^&@&2,1```CYF!
M#"4(5V```$@E`0`X)0,@^`DDI500W[\`&-^\`!`#X``()[T`(`/@``@``!`E
M)[WZX/^\!0@\'``"`YG@(2><_"C_M`3HCY2!2/^_!1C_LP3@_[$$T/^P!,C_
MO@40_[<%`/^V!/C_M03P_[($V`"`@"6/F8`LCX2`+(Z"```G.13P)(14*`"@
MF"4GI0`<KZ($O`,@^`D`````CYF!L"0%`"\"`"`E`R#X"0!`B"400``9CYF`
MU(^$@"R/F8`L`@`H)2<Y&1@#(/@))(14.`(`$"6/I`2\CH,``!2#`'3?OP48
MW[X%$-^\!0C?MP4`W[8$^-^U!/#?M`3HW[,$X-^R!-C?L030W[`$R`/@``@G
MO04@``````(`("4#(/@)CY*`+(^9@6`F151(`F`@)0,@^`D`0*@E$$#_WP!`
M0"6/EX`LCY.`+($"``"/EH`L)O=3V!!``#LF<U10`````!(@``>/F8#$`0`H
M)0(@("4#(/@)KZ@`#!!``"F/J``,CYF`U`$`("4#(/@)KZ@`#(^H``P!`A@A
M@&3__R0#`"\4@P`()$/__@$#&"$D!0`OH&```21C__^`9``!$(7__"1"__\F
MHP`!`&(0(2A"!``00/^YCYF!0">^`+@#P"`E`@!0)0)@2"4FQU18)`8$``,@
M^`D``"@ECYF!C">E`"`#(/@)`\`@)11```6/H@`H-`.``#!"\``00P`5CYF!
M"(^9@6`F151(`R#X"0``("400/^A`$!`)8$"```40/_(`````!(@``:/F8#$
M`N`H)0,@^`D"("`E$$#_\H^9@6`"X$`E$`#_UR0"``$`````)`4``0,@^`D#
MP"`E%$#_Z8^9@6"/A(`LCYF`+`/`*"4G.1D8`R#X"22$5#B/F8#T`R#X"0/`
M("40`/^*`````(^9@7@#(/@)``````````"`@P``$&``"`"`$"4D!0`O%&4`
M`B2$``$`@!`E@(,``!1@__L``````^``"``````GO?_@_[P`$#P<``(#F>`A
M_[\`&/^Q``C_L```$(``("><^6B`D0``$B``'0"`@"6/F8#4`R#X"0`````D
M0O__`@(0(0("&"L08``E)`,`+X!$```4@P`>)`0`+Q````4D0O__`````%1D
M`!DD!``O)$+__U8"__R`0P``)`(`+Q(B`#6/F8#TCX2`+`,@^`DDA%10$```
M!]^_`!@`````CX2`+(^9@/0#(/@))(13V-^_`!C?O``0W[$`"-^P```#X``(
M)[T`(%!D``LD!``O)$+__P("&"M48/_[@$,``%("_^<D`@`O$````R0$`"\4
M9``&`%`P(R1"__\"`A@K5&#_^X!#````4#`C),(``BQ"!`$00``.CY&`/(^9
M@6@"`"@E)B2;T"0'!``#(/@)),8``=^_`!@F(IO0W[P`$-^Q``C?L````^``
M"">]`"`0`/_7```0)8^$@"P#(/@))(13V!``_]/?OP`8`````">]_X#_O`!P
M/!P``@.9X"$GG/?XCX.`7/^S`%"/DX%(_[``.(^0@"S_OP!X)&*3`/^V`&C_
MM0!@_[0`6/^R`$C_L0!`CX2`+-QGDP#<1@`(W$4`$-Q#`!B.:```E$(`("80
M%D`"`,@E)(148*^H`"S_IP`(_Z8`$/^E`!C_HP`@`R#X":>B`"B/A(`L`@#(
M)8^4@"P#(/@))(14<(^$@"P"`,@ECY6`+`,@^`DDA%1XCX2`+`(`R"6/EH`L
M`R#X"22$5(@"`,@E`R#X"2:$5)"/A(`L`@#()8^1@"P#(/@))(14H`(`R"4#
M(/@))J14*`(`R"4#(/@))L14L`(`R"4#(/@))B14P(^$@"P"`,@E)[(`!`,@
M^`DDA%30CX2`+`(`R"6/D(`L`R#X"22$5#B/A(`L)A`4\`)`*"4"`,@E`R#X
M"22$5.!00``OCY&`+"8D5,"/D8`L)C$9&`(@R"4#(/@)`$`H)8^$@"P"0"@E
M`@#()0,@^`DDA%3X$$``!0!`*"6/A(`L`B#()0,@^`DDA%40CX2`+`)`*"4"
M`,@E`R#X"22$52`00``9`$`H)0(@R"4#(/@))J14*(^%@"PFA%20`B#()0,@
M^`DDI558CZ,`+(YB```48@`GW[\`>-^\`'#?M@!HW[4`8-^T`%C?LP!0W[(`
M2-^Q`$#?L``X`^``"">]`(`0`/_7)C$9&(^$@"P"0"@E`@#()0,@^`DDA%4P
M%$``#H^9@:R/A8`L)`8`"B2E54@#(/@))Z0`&51`_]^/A8`L)Z4`(P(@R"4#
M(/@))L14L!``_]F/A8`L`$`H)0(@R"4#(/@))L14L!``_]./A8`LCYF!>`,@
M^`D``````````">]_]#_O``@/!P``@.9X"$GG/5P_[$`&/^P`!"/D8`\CY"!
M2/^_`"B.(IF0C@0``"0#__^OI``,$$,`"X^$@"R/I``,C@,``!2#`!??OP`H
MW[P`(-^Q`!C?L``0`^``"">]`#``````CYF`+">E``@G.13P`R#X"22$5+!0
M0``(```0)8!#```08``#```0)3AB`#```A`K$`#_Z:XBF9`0`/_GKB*9D(^9
M@7@#(/@)```````````GO?_P_[P``#P<``(#F>`A)YSTN(^9@-S_OP`(`R#X
M"0````"/F8#D`R#X"0!`("500``"```0)8Q"``#?OP`(W[P```/@``@GO0`0
M`````">]_[#_O`!`/!P``@.9X"$GG/1H_[$`((^1@4C_LP`P_[(`*/^_`$C_
MM``X_[``&(^2@"R/F8`LCB(```"`F"4GI0`()D158"<Y%/"OH@`,`R#X"0``
M```00``E`$"`)8!"```00``BCYF!N`)@*"4#(/@)`@`@)11``"*/F8#4`R#X
M"0)@("6/F8#4`@`@)0,@^`D`0*`ECYF`R`*"$"$#(/@))$0``H^'@"R/A8`L
MCYF`X`!`("4"`$`E).=42`)@,"4DI518`R#X"0!`H"6/F8`L`H`H)2<Y&1@#
M(/@))D158!````<``````````(^9@"P"8"@E)SD9&`,@^`DF1%5@CZ,`#(XB
M```48@`)W[\`2-^\`$#?M``XW[,`,-^R`"C?L0`@W[``&`/@``@GO0!0CYF!
M>`,@^`D`````)[V`$/^\?]@\'``"`YG@(2><\RC_OG_@CYZ!2/^U?\#_LW^P
M_[)_J/^P?YC_OW_H_[=_T/^V?\C_M'^X_[%_H(^&@"PGO?Y0)Z@`$#P"__\`
M@*@E-`2!,`"(("&/PP``)$5^W*^F``P`A2@A),14*#0&@2P`R#`AK,,``(^#
M@"PT!X$P`.@X(0#B$"$D8U6`K$-^X(^#@"R/DH`LCY"`+"1C4]BL0W[DCX.`
M+(^3@"PF4E40)&-5B*Q#?P2/@X`L)A!5<"9S%/`D8U60K$-_"(^#@"RL0'[H
MK%)_`"1C59BL0W\,CX.`+*Q`?Q2L4'[P)&-5H*Q#?Q"/@X`LK$!^^`)@R"4D
M8U6H`R#X":Q#?O000``$CYF`:(!#``!48`#:CYF`;`,@^`D`````$$``X`!`
MN"6/F8#4`R#X"0+@("6/F8#(``(00`,@^`DD1``!@N,``!!@``T`0(@ECX*`
M+`(@@"4D5%6XDN8``(^9@.`"`"`E`H`H)0,@^`DF]P`!@N(``!1`__@F$``"
M/`+__R>D`!`T`X$P`&08(210?P"/E(`L`'"`(2>E`!`T`X$P)$)^W`!E&"$"
M0"`E)I0;^!````8`8I`A)A``!`````".!```4(``:CP6__\"8,@E`R#X"0)`
M*"400/_W`$"P)8!"``!00/_V)A``!`*`R"4#(/@)`L`@)5!`__$F$``$CYF`
M]`,@^`D"P"`E$$``5@!`,"4`````CYF`U```````P"`E`R#X":^F``B/F8#4
M`B`@)0,@^`D`0(`E`@(0(8^9@,@D4`0$`R#X"0(`("6/E(`LCXB`+(^%@"R/
MI@`(CYF`X`!`("4"($@E)0A5P":'5%`DI57(`R#X"0!`D"6/F8$4)`4!P`,@
M^`D"0"`E)`/__Q!#`&*/F8$<CYF!E">C`!`\%O__-`*!,`!#$"$FQ7\8`$4H
M(0,@^`D"0"`E%$``"@!`B"4GHP`0-`*!,`!#$"$`5K@ACN)_("0#0``P0O``
M4$,`G([C?S2/A8`LCX2`S(^9@82.I@```D`X)22E5A@DA`"P`R#X"0``@"4G
MHP`0-`*!+`!#$"&,1```C\,``!2#`;L"`!`E)[T!L-^_?^C?OG_@W[Q_V-^W
M?]#?MG_(W[5_P-^T?[C?LW^PW[)_J-^Q?Z#?L'^8`^``"">]?_``````/!;_
M_P`````T`X$P)Z0`$(^4@"PFPG[@`&08(0!B$"$``)`EKZ(`"":4&_@T`H$P
M)Z,`$`!#$"$`$KB``%80(0!7$"&,4'[@$@#_F0``,"6"`@``$$``#8^B``@`
M5[@A`H#()0,@^`D"`"`E%$``"B92``&.\``$$@#_C0``,"6"`@``%$#_]B;W
M``00`/^(```P)0````"/F8#T`R#X"0(`("400/_A`$`P)1``_X*/F8#4````
M``,@^`D`````C$,``"0"`!$08O^;CYF!E(^9@1R.I@````"`)0,@^`FOI@`(
MCX6`+(^$@,R,2```CYF!A(^F``@"0#@E)*55V`,@^`DDA`"P$`#_J">C`!``
M0"`E`R#X":^B``B/H@`(CYF`]`,@^`D`0"`E$`#_G@!`@"4`````/!;__R>C
M`!`T`H$P`$,0(2;4?O``5*`A-`*!,";1?MP`0Q`A`@`@)0``N"4``(`E`%&(
M(1"```P"E[@A`F#()0,@^`D"("@E$$``!"80``&`0P``%&``#(^9@/2.Y``$
M%(#_]B;W``2/F8#(CY>`+`,@^`DD!``-`$"()1``_PLF]U5X``````,@^`D`
M0"`E%$#^_`!`N"4T`H$P)Z,`$`!#$"$`$+B``%80(0!7$"$0`/_@C$1^\(^9
M@-P#(/@)KZ,`"(^C``@48O]ACX6`+([B?R`D`P'`,$(!_Q1#_UV/A(#,CYF`
MR`,@^`D"`"`E)Z0`$#0#@3``9!@ACX2`+";%?MP`92@A)(16<`)@R"4#(/@)
M`$"`)1!``&N/F8#TCK,```,@^`D`0"`ECYF`<`)@("4#(/@)`$`H)1!``&(`
M0)@ECYF`U`,@^`D"8"`E`$"P)2Q"``040``3CYF`=(^%@"R/F8#$)L3__"2E
M5G@#(/@)`F0@(11```N/F8!T)`(`!!+"`,@"=K`A@L/_^R0"`"]08@#&CK4`
M!`````"/F8!T``````,@^`D`````%$``"(^"@"R/F8#H`F`@)0,@^`D``"@E
M%$``00!`F"6/@H`LCX6`+(^$@"PD61D8)*556"2$5+`#(/@)K[D`"(^9@02/
MDX`L`R#X"8^5@"R/A8`LCYF`X"9I5V``0$`E)H=44`)`,"4DI5:8`R#X"0(`
M("4D%O__)!<`$29S5V`0```1)K56J`,@^`D`````C$(``!17`!*/F8$$`R#X
M"28Q``&/F8#@`F!0)0(@2"4`0$`E)H=44`)`,"4"H"@E`R#X"0(`("6/F8$4
M)`4!P`,@^`D"`"`E$%;_ZX^9@1R/F8&D`R#X"0)`("6/H@`,C[D`"`(`*"4#
M(/@))$14*(^9@&P#(/@)`@`@)1``_NTGHP`0`````!``_YZ.LP``CYF`[`!`
M("4D!@`"`R#X"20%_^X\$?__)Z,`$#0"@3``0Q`A)C5_^(^9@3P`5:@A)`8`
M!@*@*"4#(/@)`F`@)2>C`!`T`H$P`$,0(0!1B"&2(W_X%&``!"0$`$.2(W_Y
M4&0`<)(E?_J/F8#L```P)0``*"4#(/@)`F`@)8^9@'@\%?__`R#X"2:Q?_@`
M0+`E)Z,`$#0"@3``0Q`A$```!@!1B"$``````$`P)0(@*"4#(/@)`L`@)8^9
M@3PT!H```B`H)0,@^`D"8"`E'$#_]H^9@'R/F8&T`F`@)0,@^`DFM7^P)Z,`
M$#0"@3``0Q`ACYF`@`!5B"$"P"@E`R#X"0(@("6/@H`L-`.!,">D`!`FM0`8
M`&08(0!UJ"$F-@`4)%-5N`````"2)@``CYF`X`*@("4"8"@E`R#X"28Q``$6
MT?_Y)K4``B>D`!`T`X$P`&08(3P"__^/B8`LCX6`+"1(?\B/F8#@`&(0(30#
M@3``9!@A)2E78`!H0"$FAU10`D`P)22E5H@"`"`EH$!_\`,@^`D`````CX*`
M+(^9@:0"0"`E)$(9&`,@^`FOH@`(CZ(`#(^Y``@"`"@E`R#X"21$5"B/F8!L
M`R#X"0(`("40`/YT)Z,`$(ZU``0`````$J#_.X^9@-0#(/@)`J`@)2Q#``04
M8/\XCYF`=(^%@"R/F8#$)$3__"2E5H`#(/@)`J0@(5!`_RX"H)@E$`#_+H^9
M@'0D!`!!%*3_D(^9@.R2)'_[%(/_C@``,"62)'_\)`,`2!2#_XL``"@EDB-_
M_20"`$448O^'`F`@)20&``(#(/@))`7_QH^9@3P"H"@E`F`@)0,@^`DD!@`I
MCXF`+(^%@"P"H$`ECYF`X"4I5V`FAU10`D`P)22E5H@0`/^\`@`@)8^9@7@#
M(/@)`````">]_Z#_O`!0/!P``@.9X"$GG.CX_[0`0(^4@4C_OP!8_[$`*/^P
M`"#_M0!(_[,`./^R`#".@@``CYF`T">$@="OH@`<`R#X"8^0@"R,0@``CX2`
M+)!#`&0GL0`8)A`4\`(@*"4DA%20`@#()0,@^`F@0P!E$$``!"0#`#&`1```
M4(,`=X!"``&/F8"$`R#X"0````"/F8#0`R#X"2>$@="/A8`LC$0``(^9@40D
M!P`#)`8``22E5L`#(/@)`$"0)1!``!"/AH`LC$,`#(Y$``",90``CYF!;"3&
M5L@#(/@)KZ(`#(^B``P\`P!`C$(`#(Q%``",H@`(`$,0)!1``&P`````CYF`
MT`,@^`DGA('0CX6`+(Q$``"/F8%$)`<``R0&``$DI5;0`R#X"0!`D"400``.
M`$"8)8^$@"P"("@E`@#()0,@^`DDA%0X$$``2(^9@(B.8P`,CD0``(^9@6R,
M90```R#X"0!`,"6/F8#0)X2!T`,@^`F/E8`\C%,``(^%@"R/F8$T`F`@)20&
M``$DI5;8`R#X"0!`D"6/AH`LCYF!;`!`*"4"8"`E`R#X"23&5O".0@``CX2`
M+`(@*"6@0`!E`@#()0,@^`DDA%0H$$``&:ZBG]2/F8$4)`4!P`,@^`D`0"`E
M)`,`$1!#``0D0P`!+&,``A!@`#*/@X`\CZ,`'(Z"```48@`_W[\`6-^\`%#?
MM0!(W[0`0-^S`#C?L@`PW[$`*-^P`"`#X``()[T`8`````"/@H`\CYF`C`,@
M^`F,1)_8%$#_XZZBG]2/A(`LCYF!,`,@^`DDA%;X4$#_C8^9@-`0`/^(CYF`
MA`,@^`D`````CF,`#!!``!J.1```CYF!;(QE````0#`E`R#X":^B``R/H@`,
MCYF!I`,@^`D`0"`E$`#_L8^9@-"/F8$8`R#X"8Y$```0`/^2CYF`T(^$@"R.
MII_4C&.?V(^9@3``0#@EC&4```,@^`DDA%<@`````(^"@#R/F8%LC&4``(Q"
MG]@#(/@)C$8``!``_YN/F8#0CYF!>`,@^`D``````````">]_^#_O``0/!P`
M`@.9X"$GG.7@CYF`D/^_`!C_L0`(_[````,@^`D`@(`ECYF`E`,@^`D`0"`E
MCYF`=`,@^`D`0(@E$$``#M^_`!A2```-W[P`$(("```00``)CX6`+(^9@:PD
M!@`$)*55P`,@^`D"("`E$$``"(^9@"S?OP`8W[P`$-^Q``C?L````^``"">]
M`"``````W[\`&-^\`!#?L0`(`@`@)=^P```G.1<H`R``"">]`"``````````
M`">]_I#_O`%@/!P``@.9X"$GG.4@CXF!2/^_`6C_L0%8_[`!4(TB```GI0`(
M)(,`'*^B`4PGIP!(`*`0)0````",9@``)$(`!"1C``041__\K$;__"2H`0",
MHP`T`````(RB`"",IP`(C*8```!B$"8`1Q`F`$80)@`"&$```A?"`&(0):RB
M`$`DI0`$507_](RC`#2,C```C(T`"(R*``R/HP`(C(L`!(R.`!`\`EJ")$)Y
MF0`,1L(`8A@A``PY0`&J,"8`Z#@E`&X8(0#+,"0`9Q@A`,HP)@!F&"$`"WB"
MCZ8`#``++X``KR@E`:5`)@$,0"0`PC`A`0U`)@#*,"$`##B"``Q_@`$&0"&/
MI@`0`>=X)0`#QL(``SE``/C`)0"O."8!&$`A`.,X)``#P((`PC`A``,?@`!X
M&"4`S3`A``C.P@#E."8`",%``QG`)0#F."$`^#@AC[@`%`'C,"8`",B"`P+`
M(0#(,"0`"$>``1E`)0,%*"$`!\["`,\P)@`'P4`#&<`E`,4P(0#8,"&/N``8
M`&@H)@`'R((#`L`A`*<H)``'/X``^3@E`P]X(0`&SL(`HR@F``;!0`,9P"4`
MKR@A`+@H(8^X`!P!!W@F``;(@@,"P"$!YG@D``8W@`#9,"4!Z'@F``7.P@,#
M&"$`!<%``QG`)0'C&"$`>!@AC[@`(`#F>"8`!<B"`P+`(0'E>"0`!2^``+DH
M)0'G>"8``\["`PA`(0`#P4`#&<`E`>A`(0$80"&/N``D`,5X)@`#R((#`L`A
M`>-X)``#'X``>1@E`>9X)@`(SL(#!S@A``C!0`,9P"4!YS@A`/@X(8^X`"@`
MHW@F``C(@@,"P"$!Z'@D``A'@`$90"4!Y7@F``?.P@,&,"$`!\%``QG`)0'F
M,"$`V#`AC[@`+`!H>"8`!\B"`P+`(0'G>"0`!S^``/DX)0'C>"8`!L["`P4H
M(0`&P4`#&<`E`>4H(0"X*"&/N``P`0=X)@`&R((#`L`A`>9X)``&-X``V3`E
M`>AX)@`%SL(#`Q@A``7!0`,9P"4!XQ@A`'@8(8^X`#0`YG@F``7(@@,"P"$!
MY7@D``4O@`"Y*"4!YW@F``/.P@,(0"$``\%``QG`)0'H0"$!&$`AC[@`.`#%
M>"8``\B"`P+`(0'C>"0``Q^``'D8)0'F>"8`",["`P<X(0`(P4`#&<`E`><X
M(0#X."&/N``\`*-X)@`(R((#`L`A`>AX)``(1X`!&4`E`>5X)@`'SL(#!C`A
M``?!0`,9P"4!YC`A`-@P(8^X`$``:'@F``?(@@,"P"$!YW@D``<_@`#Y."4!
MXW@F``;.P@,%*"$`!L%``QG`)0'E*"$`N"@AC[@`1`$'>"8`!LB"`P+`(0'F
M>"0`!C>``-DP)0'H>"8`!<["`P,8(0`%P4`#&<`E`>,8(0!X&"&/N`!(`.9X
M)@'E>"0#`L`A`>=X)@,(0"$`!<B"`>A`(0`%+X"/KP!,`+DH)0`#P4```\["
M`QG()0#%P"8!XG@A`P/`)`'G."$#!L`F`1E`(0,'P"$``\B"CZ<`4``#'X``
M>1@E``AY0``(SL(!^<@E`*-X)@#B."$!Z'@D`.8P(0'E>"8#&<`A`>9X(0`(
MR(*/I@!4``A'@`$90"4`&#E``!C.P@#YR"4`:#@F`,(0(0#X."0`12@A`.,X
M)@'Y>"$`Y3@ACZ4`6``/SL(`&(""``\Q0``8QX`\`F[9-$+KH0,0P"4`V3`E
M`.8X(0"B*"$!&#`F`,\P)@`'SL(`HR@A``<90`!Y&"4`IB@A`*,H(8^C`%P`
M#X""``]_@`'P>"4`8A@A`P\P)@!H0"$`!<["`,<P)@`%&4``!X""`'D8)0$&
M,"$`!S^``,,P(0#P."6/HP!@`>?()@,ER"8`!8B"``5'@(^E`&0`8A@A`1%`
M)0!X&"$`>1@A`*(H(0#HR"8`!H;"`R;()@`&B((`!L%``*\H(0`&?X"/I@!H
M`?%X)0,0P"4`>!@A`+DH(0#","$!#\@F``.&P@,CR"8``XB"``/!0`#',"$`
M`S^`CZ,`;`#Q."4#$,`E`+@H(0#9,"$`8A@A`>?()@`%AL(#)<@F``6(@@`%
MP4``:!@A``5'@(^E`'`!$4`E`Q#`)0#8,"$`>1@A`*(H(0#HR"8`!H;"`R;(
M)@`&B((`!L%``*\H(0`&?X"/I@!T`?%X)0,0P"4`>!@A`+DH(0#","$!#\@F
M``.&P@,CR"8``XB"``/!0`#',"$``S^`CZ,`>`#Q."4#$,`E`+@H(0#9,"$`
M8A@A`>?()@`%AL(#)<@F``6(@@`%P4``:!@A``5'@(^E`'P!$4`E`Q#`)0#8
M,"$`>1@A`*(H(0#HR"8`!H;"`R;()@`&B((`!L%``*\H(0`&?X"/I@"``?%X
M)0,0P"4`>!@A`+DH(0#","$!#\@F``.&P@,CR"8``XB"``/!0`#',"$``S^`
MCZ,`A`#Q."4#$,`E`+@H(0#9,"$`8A@A`>?()@`%AL(#)<@F``6(@@`%P4``
M:!@A``5'@(^E`(@!$4`E`Q#`)0#8,"$`>1@A`*(H(0#HR"8`!H;"`R;()@`&
MB((`!L%``*\H(0`&?X"/I@",`Q#`)0!X&"$!\7@E``.&P@`#P4``N2@A`,(P
M(0$/R"8#$,`E`R/()@`#B((`QS`A``,_@(^C`)``N"@A`/$X)0`%AL(`!<%`
M`Q#`)0#9,"$`8A@A`>?()@#8,"$#)<@F``6(@@!H&"$`!4>`CZ4`E``&AL(`
M!L%``1%`)0,0P"4`>1@A`'@8(0"B*"$`Z,`F`P;`)@`#SL(`KR@A``-Y0`'Y
M>"4`N"@A`*\H(8^O`)@`!H""``8W@`#0,"4!XG@A`0;()@,CR"8``XB"`><X
M(0`#?X"/HP"<`?%X)0`%AL(`!<%``Q#`)0#Y."$`8A@A`,_()@#X."$#)<@F
M``6(@@!H&"$`!4>`CZ4`H``'AL(`!\%``1%`)0,0P"4`>1@A`'@8(0"B*"$!
MZ,`F`P?`)@`#SL(`IC`A``,I0`"Y*"4`V#`A`,4P(8^E`*0`!X""``<_@`#P
M."4``\B"`*(H(0`#QX`!!Q`F`QG`)0!#&"8`!L["`*\H(0`&>4`!^7@E`*,H
M(0"O*"&/KP"H/`*/&S1"O-P`^!@E`/C()`'B>"$`9A@D`>A`(0!Y&"4`!7E`
M``7.P@'Y>"4`:!@A`&\8(0`&@(*/KP"L``8W@`#0,"4#!D`E`P;()`'B>"$!
M!4`D`><X(0$90"4``WE```/.P@'Y>"4!!T`A`0]`(0`%@(*/KP"P``4O@`"P
M*"4`Q3@E`,7()`'B>"$`XS@D`?C`(0#Y."4``X""`/@X(0`#'X"/N`"T`'`8
M)0`(>4``",["`?G()0"C>"4`^3@A`P+`(0"CR"0!Z'@D`?EX)0,&,"$`!\["
M``?!0`,9P"4!YC`A`-@P(0`(@(*/N`"X``A'@`$00"4`:'@E`&C()`,"P"$!
MYW@D`?EX)0,%*"$`!L["``;!0`,9P"4!Y2@A`+@H(0`'@(*/N`"\``<_@`#P
M."4!!W@E`0?()`,"P"$!YG@D`?EX)0,#&"$`!<["``7!0`,9P"4!XQ@A`'@8
M(0`&@(*/N`#```8W@`#0,"4`YG@E`.;()`,"P"$!Y7@D`?EX)0,(0"$``\["
M``/!0`,9P"4!Z$`A`1A`(0`%@(*/N`#$``4O@`"P*"4`Q7@E`,7()`,"P"$!
MXW@D`?EX)0,'."$`",["``C!0`,9P"4!YS@A`/@X(0`#@(*/N`#(``,?@`!P
M&"4`HW@E`*/()`,"P"$!Z'@D`?EX)0,&,"$`!\["``?!0`,9P"4!YC`A`-@P
M(0`(@(*/N`#,``A'@`$00"4`:'@E`&C()`,"P"$!YW@D`?EX)0,%*"$`!L["
M``;!0`,9P"4!Y2@A`+@H(0`'@(*/N`#0``<_@`#P."4!!W@E`0?()`,"P"$!
MYG@D`?EX)0,#&"$`!<["``7!0`,9P"4!XQ@A`'@8(0`&@(*/N`#4``8W@`#0
M,"4`YG@E`.;()`,"P"$!Y7@D`?EX)0,(0"$``\["``/!0`,9P"4!Z$`A`1A`
M(0`%@(*/N`#8``4O@`"P*"4`Q7@E`,7()`,"P"$!XW@D`?EX)0,'."$`",["
M``C!0`,9P"4!YS@A`/@X(0`#@(*/N`#<``,?@`!P&"4`HW@E`*/()`,"P"$!
MZ'@D`?EX)0,&,"$`!\["``?!0`,9P"4!YC`A`-@P(0`(@(*/N`#@``A'@`$0
M0"4`:'@E`&C()`,"P"$!YW@D`?EX)0,%*"$`!L["``;!0`,9P"4!Y2@A`+@H
M(0`'@(*/N`#D``<_@`#P."4!!W@E`0?()`,"P"$!YG@D`?EX)0,#&"$`!<["
M``7!0`,9P"4!XQ@A`'@8(0`&@(*/N`#H``8W@`#0,"4`YG@E`.;()`,"P"$!
MY7@D`?EX)0,(0"$`!8""`>A`(0`%+X"/KP#L`+`H)0`#P4```\["`QG()0#%
MP"4!&4`A`>)X(0#%R"0#`\`D`><X(0,9P"4`"'E```C.P@'Y>"4#!\`A`P_`
M(0`#@(*/KP#P``,?@`!P&"4`HS@E`*/()`'B>"$`Z#@D`>8P(0#Y."4`&'E`
M`!C.P@'Y>"4`YC@A`.\X(0`(@(*/KP#T``A'@`$00"4`:#`E`&C()`'B$"$`
MV#`D`$4H(0#9,"4`Q3`ACZ4`^``'SL(`&(""``=Y0``8QX`\`LIB-$+!U@,0
MP"4!^7@E`,\P(0"B*"$!&'@F`>=X)@`&SL(`HR@A``890`!Y&"4`KR@A`*,H
M(8^C`/P`!X""``<_@`#P."4#!W@F`&(8(0!H0"$`!8;"`>88)@`&B((`!<E`
M``9_@`'Q>"4#,,@E`0,8(8^F`0``>1@A`._()@,ER"8`!8B"``5'@(^E`00`
MPC`A`1%`)0#8,"$`V3`A`*(H(0'HR"8``X;"`R/()@`#B((``\%``*<H(0`#
M/X"/HP$(`/$X)0,0P"4`V#`A`+DH(0!B&"$!!\@F``:&P@,FR"8`!HB"``;!
M0`!O&"$`!G^`CZ8!#`'Q>"4#$,`E`+@H(0!Y&"$`PC`A`._()@`%AL(#)<@F
M``6(@@`%P4``R#`A``5'@(^E`1`!$4`E`Q#`)0!X&"$`V3`A`*(H(0'HR"8`
M`X;"`R/()@`#B((``\%``*<H(0`#/X"/HP$4`/$X)0,0P"4`V#`A`+DH(0!B
M&"$!!\@F``:&P@,FR"8`!HB"``;!0`!O&"$`!G^`CZ8!&`'Q>"4#$,`E`+@H
M(0!Y&"$`PC`A`._()@`%AL(#)<@F``6(@@`%P4``R#`A``5'@(^E`1P!$4`E
M`Q#`)0!X&"$`V3`A`*(H(0'HR"8``X;"`R/()@`#B((``\%``*<H(0`#/X"/
MHP$@`/$X)0,0P"4`V#`A`+DH(0!B&"$!!\@F``:&P@,FR"8`!HB"``;!0`!O
M&"$`!G^`CZ8!)`'Q>"4#$,`E`+@H(0!Y&"$`PC`A`._()@`%AL(#)<@F``6(
M@@`%P4``R#`A``5'@(^E`2@!$4`E`Q#`)0!X&"$`V3`A`*(H(0'HR"8``X;"
M`R/()@`#B((``\%``*<H(0`#/X"/HP$L`/$X)0,0P"4`V#`A`+DH(0!B&"$!
M!\@F``:&P@,FR"8`!HB"``;!0`!O&"$`!G^`CZ8!,`,0P"4`N"@A`?%X)0`%
MAL(`!<%``'D8(0#","$`[\@F`Q#`)0,ER"8`!8B"`,@P(0`%1X"/I0$T`'@8
M(0$10"4``X;"``/!0`,0P"4`V3`A`*(H(0'HR"8`V#`A`R/()@"G*"$``XB"
M``,_@(^C`3@`!H;"``;!0`#Q."4#$,`E`+DH(0"X*"$`8A@A`0?`)@,&P"8`
M!<["`&\8(0`%>4`!^7@E`'@8(0!O&"&/KP$\``:`@@`&-X``T#`E`>)X(0#F
MP"8#!<`F``/.P@'H0"$``WE``1A`(0'Y>"4!#W@ACZ@!0``%@((`!2^``+`H
M)0#%P"8!`D`A`0<X(0,#0"8`Z#@ACZ@!1``#@((`#\%```_.P@`#'X``<!@E
M`0(0(0,9P"4`HT`F`/@X(0!,$"$`1C`A``=FP@$/$"8`!T%``0Q`)0#"$"$`
M2!`AK((````/,((`#Q>`CZP!3(TH````PA`E`6<X(0!-:"$!0Q@A`<4H(:R'
M``2LC0`(K(,`#!6(``>LA0`0W[\!:-^\`6#?L0%8W[`!4`/@``@GO0%PCYF!
M>`,@^`D`````)[W_\/^\```\'``"`YG@(2><TM"/F8#(_[\`"`,@^`DD!`!@
M/`/,761C;G\\!`!G``,<.&2$12-D8P@9``0E^``#''AD8U1V-(3WYSP&_#W\
M0P`(``0D>&3#+A]DA*N)``,9//Q$``#\0P`0K$``&*Q``%S?OP`(W[P```/@
M``@GO0`0`````">]_[#_O`!`_[8`./^U`##_L0`0_[``"/^_`$C_M``H_[,`
M(/^R`!B,@P`4`,"H)0`5$,",A@`8`$,0(0"`L"4`0Q@KC(0`7`##,"$\'``"
M`!4?0@.9X"$`9A@A)YS22`"@B"6NP@`4KL,`&!"``"0FT``<)`(`0`!$$",`
M51@J%&``80*@D"6/F8&``D`P)0(@*"4#(/@)`@0@(8["`%PD`P!``D(0(1!#
M``VNP@!<W[\`2-^\`$#?M@`XW[4`,-^T`"C?LP`@W[(`&-^Q`!#?L``(`^``
M"">]`%``````CY2`+``````"P"`E`K*H(R:4-)`"@,@E`R#X"0(RB"$JH@!`
M%$``+X^4@"PFM?_``!61@B93``$`$YF``C.8(2:4-)!J*0``:B@`"&HG`!!N
M*0`':B8`&&HE`"!J)``H:B,`,&HB`#AN*``/;B<`%VXF`!]N)0`G;B0`+VXC
M`#=N(@`_L@D``+8)``>R"``(M@@`#[('`!"V!P`7L@8`&+8&`!^R!0`@M@4`
M)[($`"BV!``OL@,`,+8#`#>R`@`XM@(`/P+`("4"@,@E`R#X"28Q`$!6,__<
M:BD````2D8`"LJ@CCYF!@`*@,"4"("@E`R#X"0(`("6NU0!<W[\`2-^\`$#?
MM@`XW[4`,-^T`"C?LP`@W[(`&-^Q`!#?L``(`^``"">]`%"/F8&``$"0)0)`
M,"4"("@E`R#X"0($("&.P@!<)`,`0`)"$"$40_^@KL(`7!``_ZR/E(`L````
M`">]_\#_O``P_[4`*/^Q``C_L```_[\`./^T`"#_LP`8_[(`$(RR`!0\'``"
M)+4`'``2$,(P0@`_)$,``0.9X"$`H(`E)YS0"`*B$"$`@(@E*&4`.20$_X".
M$P`8CYF!4*!$```4H`!:`J,@(8^4@"PD!@!``,,P(P``*"4#(/@))I0TD`*`
MR"4#(/@)`@`@)8^9@5`D!@`X```H)0,@^`D"H"`E`!-&`@`3/`(`$S("`!(N
M`@`2'`(`$A("`@`@):((`%2B!P!5H@8`5J(3`%>B!0!8H@,`6:("`%H"@,@E
M`R#X":(2`%N2`@``CYF!I`(`("6B(@``E@(``*(B``&.`@````(2`J(B``*.
M`@``HB(``Y("``2B(@`$E@(`!*(B``6.`@`$``(2`J(B``:.`@`$HB(`!Y("
M``BB(@`(E@(`"*(B``F.`@`(``(2`J(B``J.`@`(HB(`"Y("``RB(@`,E@(`
M#*(B``V.`@`,``(2`J(B``Z.`@`,HB(`#Y("`!"B(@`0E@(`$*(B`!&.`@`0
M``(2`J(B`!*.`@`0`R#X":(B`!/?OP`XW[P`,-^U`"C?M``@W[,`&-^R`!#?
ML0`(W[````/@``@GO0!`CY2`+"0&`#@`PS`C`R#X"0``*"40`/^O)I0TD```
M`````````````">]_^#_O``0/!P``@.9X"$GG,X0CX*`//^_`!C_L0`(D$.;
MH!1@`!__L```CX.!P"0$``$08``%H$2;H(^"@%"/F8'``R#X"8Q$``"/D8!4
MCX*`6"8P``0"`A@K$&``#"8C``@D40`#`B.((R0"__P"(H@D`B.((8X9````
M`````R#X"280``16$?_]CAD``(^"@0`00``#CYF!``,@^`F/A(!(W[\`&-^\
M`!#?L0`(W[````/@``@GO0`@`````">]_^#_O``0/!P``@.9X"$GG,U0CX*`
M//^_`!C_L0`(D$.;H11@`!O_L```CX.!<"0$``$08``&H$2;H8^%@#R/F8%P
MCX2`2`,@^`DDI9NHCX*`'(^0@$PD0@`$`%`8*Q!@``P``H@G`C"((0`1B((`
M$8@G`!&(@`(1B"$F$/_\CAD```,@^`D`````%A'__"80__S?OP`8W[P`$-^Q
M``C?L````^``"">]`"``````)[W_H/^\`%`\'``"`YG@(2><S*#_L``@CY"!
M2/^_`%C_M0!(_[0`0/^S`#C_L@`P_[$`*(^9@3B.`@``KZ0`#*^E``BOI@`$
M)Z4`"">F``0GI``,KZ(`'`,@^`D`````CX:!*(^$@/B/F8$D`R#X"0#`*"6/
M@H%TD$(``!!``%R/F8%DCYF`T`,@^`DGA('0C$4``(^F``P\`D``D*,%!B3$
M``0`@A`K-&,``Z"C!0800`!K),8``X^9@4P`!""``R#X":^F``"/I0`(CX2`
MF(^I``R,HP``C(<``(^(@#RL0P``CX.`+"DD``*M`I_8)&-7:*Q#``2/@X`L
MK$<`"(^F```D8U=P%(``4ZQ#``P`"4"`)*,`!"1$`!``J$`AC&4``"2$``0D
M8P`$%&C__*R%__PE*0`#``E(@(^1@#R/A8`LCYF!$(XDG]P`24@AK2``````
M0"4`0#@E`R#X"22E'1`00``W`$"8)8^9@7R.))_<CY*`+`,@^`DGM``8CX2`
M+"92%/`"@"@E`D#()0,@^`DDA%2@$$``(X^5@#R/F8&0`R#X"8XDG]R/F8$@
M`R#X"0````"/I``<C@,``!2#`#0"8!`EW[\`6-^\`%#?M0!(W[0`0-^S`#C?
ML@`PW[$`*-^P`"`#X``()[T`8`,@^`D`````CX.`/!!``"BL8I_<CYF!G`,@
M^`D`0"`ECYF`T`,@^`DGA('0C$(``!``_YB@0`B+CJ2?U!"```^/F8"<`R#X
M"0`````0`/_9CYF!D(^9@/`#(/@)CB2?W!``_\8`0)@E$`#_N"0)`!"/F8#\
M`R#X"0````"/A(`L`H`H)0)`R"4#(/@))(14*`!`("400/_&KJ*?U!``_^F/
MF8"<CYF!>`,@^`D`````CYF!S`,@^`DD!``!`````(^9@!`#X'@E`R#X"208
M`&:/F8`0`^!X)0,@^`DD&`!ECYF`$`/@>"4#(/@))!@`9(^9@!`#X'@E`R#X
M"208`&*/F8`0`^!X)0,@^`DD&`!ACYF`$`/@>"4#(/@))!@`8(^9@!`#X'@E
M`R#X"208`%^/F8`0`^!X)0,@^`DD&`!>CYF`$`/@>"4#(/@))!@`78^9@!`#
MX'@E`R#X"208`%R/F8`0`^!X)0,@^`DD&`!:CYF`$`/@>"4#(/@))!@`68^9
M@!`#X'@E`R#X"208`%B/F8`0`^!X)0,@^`DD&`!7CYF`$`/@>"4#(/@))!@`
M5H^9@!`#X'@E`R#X"208`%6/F8`0`^!X)0,@^`DD&`!4CYF`$`/@>"4#(/@)
M)!@`4X^9@!`#X'@E`R#X"208`%*/F8`0`^!X)0,@^`DD&`!1CYF`$`/@>"4#
M(/@))!@`3H^9@!`#X'@E`R#X"208`$V/F8`0`^!X)0,@^`DD&`!,CYF`$`/@
M>"4#(/@))!@`2X^9@!`#X'@E`R#X"208`$J/F8`0`^!X)0,@^`DD&`!)CYF`
M$`/@>"4#(/@))!@`2(^9@!`#X'@E`R#X"208`$>/F8`0`^!X)0,@^`DD&`!&
MCYF`$`/@>"4#(/@))!@`1(^9@!`#X'@E`R#X"208`$./F8`0`^!X)0,@^`DD
M&`!"CYF`$`/@>"4#(/@))!@`08^9@!`#X'@E`R#X"208`$"/F8`0`^!X)0,@
M^`DD&``_CYF`$`/@>"4#(/@))!@`/H^9@!`#X'@E`R#X"208`#R/F8`0`^!X
M)0,@^`DD&``[CYF`$`/@>"4#(/@))!@`.H^9@!`#X'@E`R#X"208`#F/F8`0
M`^!X)0,@^`DD&``XCYF`$`/@>"4#(/@))!@`-X^9@!`#X'@E`R#X"208`#:/
MF8`0`^!X)0,@^`DD&``UCYF`$`/@>"4#(/@))!@`-(^9@!`#X'@E`R#X"208
M`#*/F8`0`^!X)0,@^`DD&``PCYF`$`/@>"4#(/@))!@`+X^9@!`#X'@E`R#X
M"208`"Z/F8`0`^!X)0,@^`DD&``MCYF`$`/@>"4#(/@))!@`+(^9@!`#X'@E
M`R#X"208`"N/F8`0`^!X)0,@^`DD&``JCYF`$`/@>"4#(/@))!@`*8^9@!`#
MX'@E`R#X"208`"B/F8`0`^!X)0,@^`DD&``GCYF`$`/@>"4#(/@))!@`)8^9
M@!`#X'@E`R#X"208`"2/F8`0`^!X)0,@^`DD&``C````````````````````
M`&>]_^#_OP`8_[P`"#P<``(GG,8P`YG@(8^9@$0$$?X``````-^_`!C?O``(
M9[T`(`/@``@```````````````!P<U]S=')I;F=S(&UI<W-I;F<*```````N
M`````````"XN````````)7,O)7,```!$>6YA3&]A9&5R.CIB;V]T7T1Y;F%,
M;V%D97(``````$EN=&5R;F%L<SHZ4$%2.CI"3T]4`````%!!4E]414U0````
M``````!005)?4%)/1TY!344`````.@`````````O`````````"5S)7,E<P``
M4$523#5,24(``````````%!%4DQ,24(`4$523#5/4%0``````````%!%4DQ)
M3P``4$%27TE.251)04Q)6D5$`%!!4E]34$%73D5$``````!005)?0TQ%04X`
M````````4$%27T1%0E5'`````````%!!4E]#04-(10````````!005)?1TQ/
M0D%,7T1%0E5'``````````!005)?1TQ/0D%,7U1-4$1)4@````````!005)?
M5$U01$E2````````4$%27T=,3T)!3%]414U0`%!!4E]'3$]"04Q?0TQ%04X`
M`````````%!!4E]#3$5!3CT````````Q`````````$Q$7TQ)0E)!4EE?4$%4
M2`!54T52`````%-94U1%30``+W1M<"\```!435!$25(``%1%35!$25(`5$5-
M4`````!435```````%5315).04U%```````````E,#)X`````'!A<BT`````
M)7,E<R5S)7,``````````"5S.B!C<F5A=&EO;B!O9B!P<FEV871E('-U8F1I
M<F5C=&]R>2`E<R!F86EL960@*&5R<FYO/25I*0H````````E<SH@<')I=F%T
M92!S=6)D:7)E8W1O<GD@)7,@:7,@=6YS869E("AP;&5A<V4@<F5M;W9E(&ET
M(&%N9"!R971R>2!Y;W5R(&]P97)A=&EO;BD*````````4$%42`````!P87)L
M`````"YP87(`````)7,E<V-A8VAE+25S)7,``"5S)7-T96UP+25U)7,````E
M<R5S=&5M<"TE=2TE=25S```````````8`````````'!E<FP`````,```````
M``!005(Z.E!A8VME<CHZ5D524TE/3@`````Q+C`U,@```%5N86)L92!T;R!C
M<F5A=&4@8V%C:&4@9&ER96-T;W)Y```````````E<SH@8W)E871I;VX@;V8@
M<')I=F%T92!C86-H92!S=6)D:7)E8W1O<GD@)7,@9F%I;&5D("AE<G)N;STE
M:2D*```````````M90```````"TM````````979A;"`G97AE8R`O=7-R+V)I
M;B]P97)L("`M4R`D,"`D>S$K(B1`(GTG"FEF(#`[(",@;F]T(')U;FYI;F<@
M=6YD97(@<V]M92!S:&5L;`IP86-K86=E(%]?<&%R7W!L.PIM>2`H)%!!4E]-
M04=)0RP@)'!A<E]T96UP+"`D<')O9VYA;64L($!T;7!F:6QE+"`E36]D=6QE
M0V%C:&4I.PI%3D0@>R!I9B`H)$5.5GM005)?0TQ%04Y]*2!["G)E<75I<F4@
M1FEL93HZ5&5M<#L*<F5Q=6ER92!&:6QE.CI"87-E;F%M93L*<F5Q=6ER92!&
M:6QE.CI3<&5C.PIM>2`D=&]P9&ER(#T@1FEL93HZ0F%S96YA;64Z.F1I<FYA
M;64H)'!A<E]T96UP*3L*;W5T<RAQ<5M296UO=FEN9R!F:6QE<R!I;B`B)'!A
M<E]T96UP(ETI.PI&:6QE.CI&:6YD.CIF:6YD9&5P=&@H<W5B('L@*"`M9"`I
M(#\@<FUD:7(@.B!U;FQI;FL@?2P@)'!A<E]T96UP*3L*<FUD:7(@)'!A<E]T
M96UP.PII9B`H+60@)'!A<E]T96UP("8F("1>3R!N92`G35-7:6XS,B<I('L*
M;7D@)'1M<"`](&YE=R!&:6QE.CI496UP*`I414U03$%412`]/B`G=&UP6%A8
M6%@G+`I$25(@/3X@1FEL93HZ0F%S96YA;64Z.F1I<FYA;64H)'1O<&1I<BDL
M"E-51D9)6"`]/B`G+F-M9"<L"E5.3$E.2R`]/B`P+`HI.PIM>2`D9FEL96YA
M;64@/2`D=&UP+3YF:6QE;F%M93L*<')I;G0@)'1M<"`\/"(N+BXB.PIX/3$[
M('=H:6QE(%L@7"1X("UL="`Q,"!=.R!D;PIR;2`M<F8@)R1P87)?=&5M<"<*
M:68@6R!<(2`M9"`G)'!A<E]T96UP)R!=.R!T:&5N"F)R96%K"F9I"G-L965P
M(#$*>#U@97AP<B!<)'@@*R`Q8`ID;VYE"G)M("<D9FEL96YA;64G"BXN+@IC
M;&]S92`D=&UP.PIC:&UO9"`P-S`P+"`D9FEL96YA;64["FUY("1C;60@/2`B
M)&9I;&5N86UE(#XO9&5V+VYU;&P@,CXF,2`F(CL*<WES=&5M*"1C;60I.PIO
M=71S*'%Q6U-P87=N960@8F%C:V=R;W5N9"!P<F]C97-S('1O('!E<F9O<FT@
M8VQE86YU<#H@)&9I;&5N86UE72D["GT*?2!]"D)%1TE.('L*26YT97)N86QS
M.CI005(Z.D)/3U0H*2!I9B!D969I;F5D("9);G1E<FYA;',Z.E!!4CHZ0D]/
M5#L*)%!!4E]-04=)0R`](")<;E!!4BYP;5QN(CL*979A;"!["E]P87)?:6YI
M=%]E;G8H*3L*;7D@)'%U:65T(#T@(21%3E9[4$%27T1%0E5'?3L*;7D@)4-O
M;F9I9R`]("@*<&%T:%]S97`@("`@/3X@*"1>3R`]?B`O7DU35VEN+R`_("<[
M)R`Z("<Z)RDL"E]E>&4@("`@("`@(#T^("@D7D\@/7X@+UXH/SI-4U=I;GQ/
M4S)\8WEG=VEN*2\@/R`G+F5X92<@.B`G)RDL"E]D96QI;2`@("`@(#T^("@D
M7D\@/7X@+UY-4U=I;GQ/4S(O(#\@)UQ<)R`Z("<O)RDL"BD["E]S971?<')O
M9VYA;64H*3L*7W-E=%]P87)?=&5M<"@I.PIM>2`H)'-T87)T7W!O<RP@)&1A
M=&%?<&]S*3L*>PIL;V-A;"`D4TE'>U]?5T%23E]??2`]('-U8B![?3L*;W!E
M;B!?1D@L("<\.G)A=R<L("1P<F]G;F%M92!O<B!L87-T.PIM>2`D8G5F.PIM
M>2`D<VEZ92`]("US("1P<F]G;F%M93L*;7D@)&-H=6YK7W-I>F4@/2`V-"`J
M(#$P,C0["FUY("1M86=I8U]P;W,["FEF("@D<VEZ92`\/2`D8VAU;FM?<VEZ
M92D@>PHD;6%G:6-?<&]S(#T@,#L*?2!E;'-I9B`H*&UY("1M(#T@)'-I>F4@
M)2`D8VAU;FM?<VEZ92D@/B`P*2!["B1M86=I8U]P;W,@/2`D<VEZ92`M("1M
M.PI](&5L<V4@>PHD;6%G:6-?<&]S(#T@)'-I>F4@+2`D8VAU;FM?<VEZ93L*
M?0IW:&EL92`H)&UA9VEC7W!O<R`^/2`P*2!["G-E96L@7T9(+"`D;6%G:6-?
M<&]S+"`P.PIR96%D(%]&2"P@)&)U9BP@)&-H=6YK7W-I>F4@*R!L96YG=&@H
M)%!!4E]-04=)0RD["FEF("@H;7D@)&D@/2!R:6YD97@H)&)U9BP@)%!!4E]-
M04=)0RDI(#X](#`I('L*)&UA9VEC7W!O<R`K/2`D:3L*;&%S=#L*?0HD;6%G
M:6-?<&]S("T]("1C:'5N:U]S:7IE.PI]"FQA<W0@:68@)&UA9VEC7W!O<R`\
M(#`["G-E96L@7T9(+"`D;6%G:6-?<&]S("T@-"P@,#L*<F5A9"!?1D@L("1B
M=68L(#0["G-E96L@7T9(+"`D;6%G:6-?<&]S("T@-"`M('5N<&%C:R@B3B(L
M("1B=68I+"`P.PHD9&%T85]P;W,@/2!T96QL(%]&2#L*;7D@)7)E<75I<F5?
M;&ES=#L*<F5A9"!?1D@L("1B=68L(#0[("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(R!R96%D('1H92!F:7)S="`B1DE,12(*=VAI;&4@*"1B=68@97$@
M(D9)3$4B*2!["G)E860@7T9(+"`D8G5F+"`T.PIR96%D(%]&2"P@)&)U9BP@
M=6YP86-K*").(BP@)&)U9BD["FUY("1F=6QL;F%M92`]("1B=68["F]U=',H
M<7%;56YP86-K:6YG($9)3$4@(B1F=6QL;F%M92(N+BY=*3L*;7D@)&-R8R`]
M("@@)&9U;&QN86UE(#U^('-\7BA;82UF7&1=>SA]*2]\?"`I(#\@)#$@.B!U
M;F1E9CL*;7D@*"1B87-E;F%M92P@)&5X="D@/2`H)&)U9B`]?B!M?"@_.BXJ
M+RD_*"XJ*2A<+BXJ*7PI.PIR96%D(%]&2"P@)&)U9BP@-#L*<F5A9"!?1D@L
M("1B=68L('5N<&%C:R@B3B(L("1B=68I.PII9B`H9&5F:6YE9"@D97AT*2!A
M;F0@)&5X="`A?B`O7"XH/SIP;7QP;'QI>'QA;"DD+VDI('L*;7D@)&9I;&5N
M86UE(#T@7W-A=F5?87,H(B1C<F,D97AT(BP@)&)U9BP@,#<U-2D["B1005(Z
M.DAE879Y.CI&=6QL0V%C:&5[)&9U;&QN86UE?2`]("1F:6QE;F%M93L*)%!!
M4CHZ2&5A=GDZ.D9U;&Q#86-H97LD9FEL96YA;65](#T@)&9U;&QN86UE.PI]
M"F5L<VEF("@@)&9U;&QN86UE(#U^(&U\7B\_<VAL:6(O?"!A;F0@9&5F:6YE
M9"`D14Y6>U!!4E]414U0?2`I('L*;7D@)&9I;&5N86UE(#T@7W-A=F5?87,H
M(B1B87-E;F%M921E>'0B+"`D8G5F+"`P-S4U*3L*;W5T<R@B4TA,24(Z("1F
M:6QE;F%M95QN(BD["GT*96QS92!["B1R97%U:7)E7VQI<W1[)&9U;&QN86UE
M?2`]"B1-;V1U;&5#86-H97LD9G5L;&YA;65](#T@>PIB=68@/3X@)&)U9BP*
M8W)C(#T^("1C<F,L"FYA;64@/3X@)&9U;&QN86UE+`I].PI]"G)E860@7T9(
M+"`D8G5F+"`T.PI]"FQO8V%L($!)3D,@/2`H<W5B('L*;7D@*"1S96QF+"`D
M;6]D=6QE*2`]($!?.PIR971U<FX@:68@<F5F("1M;V1U;&4@;W(@(21M;V1U
M;&4["FUY("1I;F9O(#T@9&5L971E("1R97%U:7)E7VQI<W1[)&UO9'5L97T@
M;W(@<F5T=7)N.PHD24Y#>R1M;V1U;&5](#T@(B]L;V%D97(O)&EN9F\O)&UO
M9'5L92(["FEF("@D14Y6>U!!4E]#3$5!3GT@86YD(&1E9FEN960H)DE/.CI&
M:6QE.CIN97<I*2!["FUY("1F:"`]($E/.CI&:6QE+3YN97=?=&UP9FEL92!O
M<B!D:64@(D-A;B=T(&-R96%T92!T96UP(&9I;&4Z("0A(CL*)&9H+3YB:6YM
M;V1E*"D["B1F:"T^<')I;G0H)&EN9F\M/GMB=69]*3L*)&9H+3YS965K*#`L
M(#`I.PIR971U<FX@)&9H.PI]"F5L<V4@>PIM>2`D9FEL96YA;64@/2!?<V%V
M95]A<R@B)&EN9F\M/GMC<F-]+G!M(BP@)&EN9F\M/GMB=69]*3L*;W!E;B!M
M>2`D9F@L("<\.G)A=R<L("1F:6QE;F%M92!O<B!D:64@<7%;0V%N)W0@<F5A
M9"`B)&9I;&5N86UE(CH@)"%=.PIR971U<FX@)&9H.PI]"F1I92`B0F]O='-T
M<F%P<&EN9R!F86EL960Z(&-A;B=T(&9I;F0@;6]D=6QE("1M;V1U;&4A(CL*
M?2P@0$E.0RD["G)E<75I<F4@6%-,;V%D97(["G)E<75I<F4@4$%2.CI(96%V
M>3L*<F5Q=6ER92!#87)P.CI(96%V>3L*<F5Q=6ER92!%>'!O<G1E<CHZ2&5A
M=GD["E!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*<F5Q=6ER92!)
M3SHZ1FEL93L*=VAI;&4@*&UY("1F:6QE;F%M92`]("AS;W)T(&ME>7,@)7)E
M<75I<F5?;&ES="E;,%TI('L*=6YL97-S("@D24Y#>R1F:6QE;F%M97T@;W(@
M)&9I;&5N86UE(#U^("]"4T1004XO*2!["FEF("@D9FEL96YA;64@/7X@+UPN
M<&UC/R0O:2D@>PIR97%U:7)E("1F:6QE;F%M93L*?0IE;'-E('L*9&\@)&9I
M;&5N86UE('5N;&5S<R`D9FEL96YA;64@/7X@+W-I=&5C=7-T;VUI>F5<+G!L
M)"\["GT*?0ID96QE=&4@)')E<75I<F5?;&ES='LD9FEL96YA;65].PI]"FQA
M<W0@=6YL97-S("1B=68@97$@(E!+7#`P,UPP,#0B.PHD<W1A<G1?<&]S(#T@
M*'1E;&P@7T9(*2`M(#0[("`@("`@("`@("`@("`@(",@<W1A<G0@;V8@>FEP
M"GT*;7D@0'!A<E]A<F=S.PIM>2`H)&]U="P@)&)U;F1L92P@)&QO9V9H+"`D
M8V%C:&5?;F%M92D["F1E;&5T92`D14Y6>U!!4E]!4%!?4D554T5].R`C('-A
M;FET:7IE("A2155312!M87D@8F4@82!S96-U<FET>2!P<F]B;&5M*0HD<75I
M970@/2`P('5N;&5S<R`D14Y6>U!!4E]$14)51WT["FEF("@A)'-T87)T7W!O
M<R!O<B`H)$%21U9;,%T@97$@)RTM<&%R+6]P=&EO;G,G("8F('-H:69T*2D@
M>PIM>2`E9&ES=%]C;60@/2!Q=R@*<"`@(&)L:6)?=&]?<&%R"FD@("!I;G-T
M86QL7W!A<@IU("`@=6YI;G-T86QL7W!A<@IS("`@<VEG;E]P87(*=B`@('9E
M<FEF>5]P87(**3L*:68@*$!!4D=6(&%N9"`D05)'5ELP72!E<2`G+2UR975S
M92<I('L*<VAI9G0@0$%21U8["B1%3E9[4$%27T%04%]2155317T@/2!S:&EF
M="!`05)'5CL*?0IE;'-E('L@(R!N;W)M86P@<&%R;"!B96AA=FEO=7(*;7D@
M0&%D9%]T;U]I;F,["G=H:6QE("A`05)'5BD@>PHD05)'5ELP72`]?B`O7BTH
M6T%)34]"3&)Q<&EU<U1V72DH+BHI+R!O<B!L87-T.PII9B`H)#$@97$@)TDG
M*2!["G!U<V@@0&%D9%]T;U]I;F,L("0R.PI]"F5L<VEF("@D,2!E<2`G32<I
M('L*979A;"`B=7-E("0R(CL*?0IE;'-I9B`H)#$@97$@)T$G*2!["G5N<VAI
M9G0@0'!A<E]A<F=S+"`D,CL*?0IE;'-I9B`H)#$@97$@)T\G*2!["B1O=70@
M/2`D,CL*?0IE;'-I9B`H)#$@97$@)V(G*2!["B1B=6YD;&4@/2`G<VET92<[
M"GT*96QS:68@*"0Q(&5Q("=")RD@>PHD8G5N9&QE(#T@)V%L;"<["GT*96QS
M:68@*"0Q(&5Q("=Q)RD@>PHD<75I970@/2`Q.PI]"F5L<VEF("@D,2!E<2`G
M3"<I('L*;W!E;B`D;&]G9F@L("(^/B(L("0R(&]R(&1I92!Q<5M#86XG="!O
M<&5N(&QO9R!F:6QE("(D,B(Z("0A73L*?0IE;'-I9B`H)#$@97$@)U0G*2![
M"B1C86-H95]N86UE(#T@)#(["GT*<VAI9G0H0$%21U8I.PII9B`H;7D@)&-M
M9"`]("1D:7-T7V-M9'LD,7TI('L*9&5L971E("1%3E9[)U!!4E]414U0)WT[
M"FEN:71?:6YC*"D["G)E<75I<F4@4$%2.CI$:7-T.PHF>R)005(Z.D1I<W0Z
M.B1C;60B?2@I('5N;&5S<R!`05)'5CL*)GLB4$%2.CI$:7-T.CHD8VUD(GTH
M)%\I(&9O<B!`05)'5CL*97AI=#L*?0I]"G5N<VAI9G0@0$E.0RP@0&%D9%]T
M;U]I;F,["GT*?0II9B`H)&]U="D@>PI["G)E<75I<F4@24\Z.D9I;&4["G)E
M<75I<F4@07)C:&EV93HZ6FEP.PIR97%U:7)E($1I9V5S=#HZ4TA!.PI]"FUY
M("1P87(@/2!S:&EF="A`05)'5BD["FUY("1Z:7`["FEF("AD969I;F5D("1P
M87(I('L*;W!E;B!M>2`D9F@L("<\.G)A=R<L("1P87(@;W(@9&EE('%Q6T-A
M;B=T(&9I;F0@<&%R(&9I;&4@(B1P87(B.B`D(5T["F)L97-S*"1F:"P@)TE/
M.CI&:6QE)RD["B1Z:7`@/2!!<F-H:79E.CI::7`M/FYE=SL**"`D>FEP+3YR
M96%D1G)O;49I;&5(86YD;&4H)&9H+"`D<&%R*2`]/2!!<F-H:79E.CI::7`Z
M.D%:7T]+*"D@*0IO<B!D:64@<7%;17)R;W(@<F5A9&EN9R!Z:7`@87)C:&EV
M92`B)'!A<B)=.PI]"FUY("5E;G8@/2!D;R!["FEF("@D>FEP(&%N9"!M>2`D
M;65T82`]("1Z:7`M/F-O;G1E;G1S*"=-151!+GEM;"<I*2!["B1M971A(#U^
M(',O+BI><&%R.B0O+VUS.PHD;65T82`]?B!S+UY<4RXJ+R]M<SL*)&UE=&$@
M/7X@+UX@("A;7CI=*RDZ("@N*RDD+VUG.PI]"GT["FEF("AD969I;F5D("1P
M87(I('L*;W!E;B!M>2`D<&@L("<\.G)A=R<L("1P87(@;W(@9&EE('%Q6T-A
M;B=T(')E860@<&%R(&9I;&4@(B1P87(B.B`D(5T["FUY("1B=68["G)E860@
M)'!H+"`D8G5F+"`T.PID:64@<7%;(B1P87(B(&ES(&YO="!A('!A<B!F:6QE
M72!U;FQE<W,@)&)U9B!E<2`B4$M<,#`S7#`P-"(["F-L;W-E("1P:#L*?0I#
M<F5A=&50871H*"1O=70I(#L*;7D@)&9H(#T@24\Z.D9I;&4M/FYE=R@*)&]U
M="P*24\Z.D9I;&4Z.D]?0U)%050H*2!\($E/.CI&:6QE.CI/7U=23TY,62@I
M('P@24\Z.D9I;&4Z.D]?5%)53D,H*2P*,#<W-RP**2!O<B!D:64@<7%;0V%N
M)W0@8W)E871E(&9I;&4@(B1O=70B.B`D(5T["B1F:"T^8FEN;6]D92@I.PIS
M965K(%]&2"P@,"P@,#L*;7D@)&QO861E<CL*:68@*&1E9FEN960@)&1A=&%?
M<&]S*2!["G)E860@7T9(+"`D;&]A9&5R+"`D9&%T85]P;W,["GT@96QS92![
M"FQO8V%L("0O(#T@=6YD968["B1L;V%D97(@/2`\7T9(/CL*?0II9B`H(21%
M3E9[4$%27U9%4D)!5$E-?2!A;F0@)&QO861E<B`]?B`O7B@_.B,A?%Q`<F5M
M*2\I('L*<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&]D4W1R:7`["E!!4CHZ1FEL
M=&5R.CI0;V13=')I<"T^87!P;'DH7"1L;V%D97(L("0P*3L*?0IF;W)E86-H
M(&UY("1K97D@*'-O<G0@:V5Y<R`E96YV*2!["FUY("1V86P@/2`D96YV>R1K
M97E](&]R(&YE>'0["B1V86P@/2!E=F%L("1V86P@:68@)'9A;"`]?B`O7ELG
M(ETO.PIM>2`D;6%G:6,@/2`B7U]%3E9?4$%27R(@+B!U8R@D:V5Y*2`N(")?
M7R(["FUY("1S970@/2`B4$%27R(@+B!U8R@D:V5Y*2`N("(])'9A;"(["B1L
M;V%D97(@/7X@<WLD;6%G:6,H("LI?7L*)&UA9VEC("X@)'-E="`N("@G("<@
M>"`H;&5N9W1H*"0Q*2`M(&QE;F=T:"@D<V5T*2DI"GUE9SL*?0HD9F@M/G!R
M:6YT*"1L;V%D97(I.PII9B`H)&)U;F1L92D@>PIR97%U:7)E(%!!4CHZ2&5A
M=GD["E!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*:6YI=%]I;F,H
M*3L*<F5Q=6ER95]M;V1U;&5S*"D["FUY($!I;F,@/2!G<F5P('L@(2]"4T10
M04XO('T*9W)E<"!["B@D8G5N9&QE(&YE("=S:71E)RD@;W(**"1?(&YE("1#
M;VYF:6<Z.D-O;F9I9WMA<F-H;&EB97AP?2!A;F0*)%\@;F4@)$-O;F9I9SHZ
M0V]N9FEG>W!R:79L:6)E>'!]*3L*?2!`24Y#.PIS?"\K?"]\9RP@<WPO)'Q\
M(&9O<F5A8V@@0&EN8SL*;7D@)69I;&5S.PHD9FEL97-[)%]]*RL@9F]R($!$
M>6YA3&]A9&5R.CID;%]S:&%R961?;V)J96-T<RP@=F%L=65S("5)3D,["FUY
M("1L:6)?97AT(#T@)$-O;F9I9SHZ0V]N9FEG>VQI8E]E>'1].R`@("`@("`@
M(",@6%A8(&QI8E]E>'0@=G,@9&QE>'0@/PIM>2`E=W)I='1E;CL*9F]R96%C
M:"!M>2`D:V5Y("AS;W)T(&ME>7,@)69I;&5S*2!["FUY("@D9FEL92P@)&YA
M;64I.PII9B`H9&5F:6YE9"AM>2`D9F,@/2`D4$%2.CI(96%V>3HZ1G5L;$-A
M8VAE>R1K97E]*2D@>PHH)&9I;&4L("1N86UE*2`]("@D:V5Y+"`D9F,I.PI]
M"F5L<V4@>PIF;W)E86-H(&UY("1D:7(@*$!I;F,I('L*:68@*"1K97D@/7X@
M;7Q>7%$D9&ER7$4O*"XJ*21\:2D@>PHH)&9I;&4L("1N86UE*2`]("@D:V5Y
M+"`D,2D["FQA<W0["GT*:68@*"1K97D@/7X@;7Q>+VQO861E<B];7B]=*R\H
M+BHI)'PI('L*:68@*&UY("1R968@/2`D36]D=6QE0V%C:&5[)#%]*2!["B@D
M9FEL92P@)&YA;64I(#T@*"1R968L("0Q*3L*;&%S=#L*?0II9B`H+68@(B1D
M:7(O)#$B*2!["B@D9FEL92P@)&YA;64I(#T@*"(D9&ER+R0Q(BP@)#$I.PIL
M87-T.PI]"GT*?0I]"FYE>'0@=6YL97-S(&1E9FEN960@)&YA;64["FYE>'0@
M:68@)'=R:71T96Y[)&YA;65]*RL["FYE>'0@:68@(7)E9B@D9FEL92D@86YD
M("1F:6QE(#U^("]<+EQ1)&QI8E]E>'1<120O:3L*;W5T<RAS<')I;G1F*'%Q
M6U!A8VMI;F<@1DE,12`B)7,B+BXN72P@<F5F("1F:6QE(#\@)&9I;&4M/GMN
M86UE?2`Z("1F:6QE*2D["FUY("1C;VYT96YT.PII9B`H<F5F*"1F:6QE*2D@
M>PHD8V]N=&5N="`]("1F:6QE+3Y[8G5F?3L*?0IE;'-E('L*;&]C86P@)"\@
M/2!U;F1E9CL*;W!E;B!M>2`D9F@L("<\.G)A=R<L("1F:6QE(&]R(&1I92!Q
M<5M#86XG="!R96%D("(D9FEL92(Z("0A73L*)&-O;G1E;G0@/2`\)&9H/CL*
M8VQO<V4@)&9H.PI005(Z.D9I;'1E<CHZ4&]D4W1R:7`M/F%P<&QY*%PD8V]N
M=&5N="P@(CQE;6)E9&1E9#XO)&YA;64B*0II9B`A)$5.5GM005)?5D520D%4
M24U](&%N9"`D;F%M92`]?B`O7"XH/SIP;7QI>'QA;"DD+VD["E!!4CHZ1FEL
M=&5R.CI0871C:$-O;G1E;G0M/FYE=RT^87!P;'DH7"1C;VYT96YT+"`D9FEL
M92P@)&YA;64I.PI]"B1F:"T^<')I;G0H(D9)3$4B+`IP86-K*"=.)RP@;&5N
M9W1H*"1N86UE*2`K(#DI+`IS<')I;G1F*"(E,#AX+R5S(BP@07)C:&EV93HZ
M6FEP.CIC;VUP=71E0U)#,S(H)&-O;G1E;G0I+"`D;F%M92DL"G!A8VLH)TXG
M+"!L96YG=&@H)&-O;G1E;G0I*2P*)&-O;G1E;G0I.PIO=71S*'%Q6U=R:71T
M96X@87,@(B1N86UE(ETI.PI]"GT*)'II<"T^=W)I=&54;T9I;&5(86YD;&4H
M)&9H*2!I9B`D>FEP.PHD8V%C:&5?;F%M92`]('-U8G-T<B`D8V%C:&5?;F%M
M92P@,"P@-#`["FEF("@A)&-A8VAE7VYA;64@86YD(&UY("1M=&EM92`]("AS
M=&%T*"1O=70I*5LY72D@>PIM>2`D8W1X(#T@1&EG97-T.CI32$$M/FYE=R@Q
M*3L*;W!E;B!M>2`D9F@L("(\.G)A=R(L("1O=70["B1C='@M/F%D9&9I;&4H
M)&9H*3L*8VQO<V4@)&9H.PHD8V%C:&5?;F%M92`]("1C='@M/FAE>&1I9V5S
M=#L*?0HD8V%C:&5?;F%M92`N/2`B7#`B('@@*#0Q("T@;&5N9W1H("1C86-H
M95]N86UE*3L*)&-A8VAE7VYA;64@+CT@(D-!0TA%(CL*)&9H+3YP<FEN="@D
M8V%C:&5?;F%M92D["B1F:"T^<')I;G0H<&%C:R@G3B<L("1F:"T^=&5L;"`M
M(&QE;F=T:"@D;&]A9&5R*2DI.PHD9F@M/G!R:6YT*"1005)?34%'24,I.PHD
M9F@M/F-L;W-E.PIC:&UO9"`P-S4U+"`D;W5T.PIE>&ET.PI]"GL*;&%S="!U
M;FQE<W,@9&5F:6YE9"`D<W1A<G1?<&]S.PI?9FEX7W!R;V=N86UE*"D["G)E
M<75I<F4@4$%2.PI005(Z.DAE879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D["GL*
M<F5Q=6ER92!&:6QE.CI&:6YD.PIR97%U:7)E($%R8VAI=F4Z.EII<#L*?0IM
M>2`D9F@@/2!)3SHZ1FEL92T^;F5W.R`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(R!!<F-H:79E.CI::7`@;W!E<F%T97,@;VX@86X@24\Z.DAA;F1L
M90HD9F@M/F9D;W!E;BAF:6QE;F\H7T9(*2P@)W(G*2!O<B!D:64@<7%;9F1O
M<&5N*"D@9F%I;&5D.B`D(5T["D%R8VAI=F4Z.EII<#HZ<V5T0VAU;FM3:7IE
M*"US(%]&2"D["FUY("1Z:7`@/2!!<F-H:79E.CI::7`M/FYE=SL**"`D>FEP
M+3YR96%D1G)O;49I;&5(86YD;&4H)&9H+"`D<')O9VYA;64I(#T]($%R8VAI
M=F4Z.EII<#HZ05I?3TLH*2`I"F]R(&1I92!Q<5M%<G)O<B!R96%D:6YG('II
M<"!A<F-H:79E("(D<')O9VYA;64B73L*07)C:&EV93HZ6FEP.CIS971#:'5N
M:U-I>F4H-C0@*B`Q,#(T*3L*<'5S:"!`4$%2.CI,:6)#86-H92P@)'II<#L*
M)%!!4CHZ3&EB0V%C:&5[)'!R;V=N86UE?2`]("1Z:7`["B1Q=6EE="`]("$D
M14Y6>U!!4E]$14)51WT["F]U=',H<7%;7"1%3E9[4$%27U1%35!](#T@(B1%
M3E9[4$%27U1%35!](ETI.PII9B`H9&5F:6YE9"`D14Y6>U!!4E]414U0?2D@
M>R`C('-H;W5L9"!B92!S970@870@=&AI<R!P;VEN="$*9F]R96%C:"!M>2`D
M;65M8F5R("@@)'II<"T^;65M8F5R<R`I('L*;F5X="!I9B`D;65M8F5R+3YI
M<T1I<F5C=&]R>3L*;7D@)&UE;6)E<E]N86UE(#T@)&UE;6)E<BT^9FEL94YA
M;64["FYE>'0@=6YL97-S("1M96UB97)?;F%M92`]?B!M>PI>"B\_<VAL:6(O
M"B@_.B1#;VYF:6<Z.D-O;F9I9WMV97)S:6]N?2\I/PHH/SHD0V]N9FEG.CI#
M;VYF:6=[87)C:&YA;65]+RD_"BA;7B]=*RD*)`I]>#L*;7D@)&5X=')A8W1?
M;F%M92`]("0Q.PIM>2`D9&5S=%]N86UE(#T@1FEL93HZ4W!E8RT^8V%T9FEL
M92@D14Y6>U!!4E]414U0?2P@)&5X=')A8W1?;F%M92D["FEF("@M9B`D9&5S
M=%]N86UE("8F("US(%\@/3T@)&UE;6)E<BT^=6YC;VUP<F5S<V5D4VEZ92@I
M*2!["F]U=',H<7%;4VMI<'!I;F<@(B1M96UB97)?;F%M92(@<VEN8V4@:70@
M86QR96%D>2!E>&ES=',@870@(B1D97-T7VYA;64B72D["GT@96QS92!["F]U
M=',H<7%;17AT<F%C=&EN9R`B)&UE;6)E<E]N86UE(B!T;R`B)&1E<W1?;F%M
M92)=*3L*)&UE;6)E<BT^97AT<F%C=%1O1FEL94YA;65D*"1D97-T7VYA;64I
M.PIC:&UO9"@P-34U+"`D9&5S=%]N86UE*2!I9B`D7D\@97$@(FAP=7@B.PI]
M"GT*?0I]"G5N;&5S<R`H)%!!4CHZ3&EB0V%C:&5[)'!R;V=N86UE?2D@>PID
M:64@/#P@(BXB('5N;&5S<R!`05)'5CL*57-A9V4Z("0P(%L@+4%L:6(N<&%R
M(%T@6R`M261I<B!=(%L@+4UM;V1U;&4@72!;('-R8RYP87(@72!;('!R;V=R
M86TN<&P@70HD,"!;("U"?"UB(%T@6RU/;W5T9FEL95T@<W)C+G!A<@HN"B1%
M3E9[4$%27U!23T=.04U%?2`]("1P<F]G;F%M92`]("0P(#T@<VAI9G0H0$%2
M1U8I.PI]"G-U8B!#<F5A=&50871H('L*;7D@*"1N86UE*2`]($!?.PIR97%U
M:7)E($9I;&4Z.D)A<V5N86UE.PIM>2`H)&)A<V5N86UE+"`D<&%T:"P@)&5X
M="D@/2!&:6QE.CI"87-E;F%M93HZ9FEL97!A<G-E*"1N86UE+"`H)UPN+BHG
M*2D["G)E<75I<F4@1FEL93HZ4&%T:#L*1FEL93HZ4&%T:#HZ;6MP871H*"1P
M871H*2!U;FQE<W,H+64@)'!A=&@I.R`C(&UK<&%T:"!D:65S('=I=&@@97)R
M;W(*?0IS=6(@<F5Q=6ER95]M;V1U;&5S('L*<F5Q=6ER92!L:6(["G)E<75I
M<F4@1'EN84QO861E<CL*<F5Q=6ER92!I;G1E9V5R.PIR97%U:7)E('-T<FEC
M=#L*<F5Q=6ER92!W87)N:6YG<SL*<F5Q=6ER92!V87)S.PIR97%U:7)E($-A
M<G`["G)E<75I<F4@0V%R<#HZ2&5A=GD["G)E<75I<F4@17)R;F\["G)E<75I
M<F4@17AP;W)T97(Z.DAE879Y.PIR97%U:7)E($5X<&]R=&5R.PIR97%U:7)E
M($9C;G1L.PIR97%U:7)E($9I;&4Z.E1E;7`["G)E<75I<F4@1FEL93HZ4W!E
M8SL*<F5Q=6ER92!84TQO861E<CL*<F5Q=6ER92!#;VYF:6<["G)E<75I<F4@
M24\Z.DAA;F1L93L*<F5Q=6ER92!)3SHZ1FEL93L*<F5Q=6ER92!#;VUP<F5S
M<SHZ6FQI8CL*<F5Q=6ER92!!<F-H:79E.CI::7`["G)E<75I<F4@1&EG97-T
M.CI32$$["G)E<75I<F4@4$%2.PIR97%U:7)E(%!!4CHZ2&5A=GD["G)E<75I
M<F4@4$%2.CI$:7-T.PIR97%U:7)E(%!!4CHZ1FEL=&5R.CI0;V13=')I<#L*
M<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&%T8VA#;VYT96YT.PIR97%U:7)E(&%T
M=')I8G5T97,["F5V86P@>R!R97%U:7)E($-W9"!].PIE=F%L('L@<F5Q=6ER
M92!7:6XS,B!].PIE=F%L('L@<F5Q=6ER92!38V%L87(Z.E5T:6P@?3L*979A
M;"![(')E<75I<F4@07)C:&EV93HZ56YZ:7`Z.D)U<G-T('T["F5V86P@>R!R
M97%U:7)E(%1I93HZ2&%S:#HZ3F%M961#87!T=7)E('T["F5V86P@>R!R97%U
M:7)E(%!E<FQ)3SL@<F5Q=6ER92!097)L24\Z.G-C86QA<B!].PIE=F%L('L@
M<F5Q=6ER92!U=&8X('T["GT*<W5B(%]S971?<&%R7W1E;7`@>PII9B`H9&5F
M:6YE9"`D14Y6>U!!4E]414U0?2!A;F0@)$5.5GM005)?5$5-4'T@/7X@+R@N
M*RDO*2!["B1P87)?=&5M<"`]("0Q.PIR971U<FX["GT*9F]R96%C:"!M>2`D
M<&%T:"`H"BAM87`@)$5.5GLD7WTL('%W*"!005)?5$U01$E2(%1-4$1)4B!4
M14U01$E2(%1%35`@5$U0("DI+`IQ=R@@0SI<7%1%35`@+W1M<"`N("D**2![
M"FYE>'0@=6YL97-S(&1E9FEN960@)'!A=&@@86YD("UD("1P871H(&%N9"`M
M=R`D<&%T:#L*;7D@)'5S97)N86UE.PIM>2`D<'=U:60["F5V86P@>R@D<'=U
M:60I(#T@9V5T<'=U:60H)#XI(&EF(&1E9FEN960@)#X[?3L*:68@*"!D969I
M;F5D*"97:6XS,CHZ3&]G:6Y.86UE*2`I('L*)'5S97)N86UE(#T@)E=I;C,R
M.CI,;V=I;DYA;64["GT*96QS:68@*&1E9FEN960@)'!W=6ED*2!["B1U<V5R
M;F%M92`]("1P=W5I9#L*?0IE;'-E('L*)'5S97)N86UE(#T@)$5.5GM54T52
M3D%-17T@?'P@)$5.5GM54T52?2!\?"`G4UE35$5-)SL*?0HD=7-E<FYA;64@
M/7X@<R]<5R]?+V<["FUY("1S=&UP9&ER(#T@(B1P871H)$-O;F9I9WM?9&5L
M:6U]<&%R+2(N=6YP86-K*")(*B(L("1U<V5R;F%M92D["FUK9&ER("1S=&UP
M9&ER+"`P-S4U.PII9B`H(21%3E9[4$%27T-,14%.?2!A;F0@;7D@)&UT:6UE
M(#T@*'-T870H)'!R;V=N86UE*2E;.5TI('L*;W!E;B!M>2`D9F@L("(\.G)A
M=R(L("1P<F]G;F%M92!O<B!D:64@<7%;0V%N)W0@<F5A9"`B)'!R;V=N86UE
M(CH@)"%=.PIS965K("1F:"P@+3$X+"`R.PIM>2`D8G5F.PIR96%D("1F:"P@
M)&)U9BP@-CL*:68@*"1B=68@97$@(EPP0T%#2$4B*2!["G-E96L@)&9H+"`M
M-3@L(#(["G)E860@)&9H+"`D8G5F+"`T,3L*)&)U9B`]?B!S+UPP+R]G.PHD
M<W1M<&1I<B`N/2`B)$-O;F9I9WM?9&5L:6U]8V%C:&4M)&)U9B(["GT*96QS
M92!["FUY("1D:6=E<W0@/2!E=F%L"GL*<F5Q=6ER92!$:6=E<W0Z.E-(03L*
M;7D@)&-T>"`]($1I9V5S=#HZ4TA!+3YN97<H,2D["F]P96X@;7D@)&9H+"`B
M/#IR87<B+"`D<')O9VYA;64@;W(@9&EE('%Q6T-A;B=T(')E860@(B1P<F]G
M;F%M92(Z("0A73L*)&-T>"T^861D9FEL92@D9F@I.PIC;&]S92@D9F@I.PHD
M8W1X+3YH97AD:6=E<W0["GT@?'P@)&UT:6UE.PHD<W1M<&1I<B`N/2`B)$-O
M;F9I9WM?9&5L:6U]8V%C:&4M)&1I9V5S="(["GT*8VQO<V4H)&9H*3L*?0IE
M;'-E('L*)$5.5GM005)?0TQ%04Y](#T@,3L*)'-T;7!D:7(@+CT@(B1#;VYF
M:6=[7V1E;&EM?71E;7`M)"0B.PI]"B1%3E9[4$%27U1%35!](#T@)'-T;7!D
M:7(["FUK9&ER("1S=&UP9&ER+"`P-S4U.PIL87-T.PI]"B1P87)?=&5M<"`]
M("0Q(&EF("1%3E9[4$%27U1%35!](&%N9"`D14Y6>U!!4E]414U0?2`]?B`O
M*"XK*2\["GT*<W5B(%]S879E7V%S('L*;7D@*"1N86UE+"`D8V]N=&5N=',L
M("1M;V1E*2`]($!?.PIM>2`D9G5L;&YA;64@/2`B)'!A<E]T96UP+R1N86UE
M(CL*=6YL97-S("@M92`D9G5L;&YA;64I('L*;7D@)'1E;7!N86UE(#T@(B1F
M=6QL;F%M92XD)"(["F]P96X@;7D@)&9H+"`G/CIR87<G+"`D=&5M<&YA;64@
M;W(@9&EE('%Q6T-A;B=T('=R:71E("(D=&5M<&YA;64B.B`D(5T["G!R:6YT
M("1F:"`D8V]N=&5N=',["F-L;W-E("1F:#L*8VAM;V0@)&UO9&4L("1T96UP
M;F%M92!I9B!D969I;F5D("1M;V1E.PIR96YA;64H)'1E;7!N86UE+"`D9G5L
M;&YA;64I(&]R('5N;&EN:R@D=&5M<&YA;64I.PI]"G)E='5R;B`D9G5L;&YA
M;64["GT*<W5B(%]S971?<')O9VYA;64@>PII9B`H9&5F:6YE9"`D14Y6>U!!
M4E]04D]'3D%-17T@86YD("1%3E9[4$%27U!23T=.04U%?2`]?B`O*"XK*2\I
M('L*)'!R;V=N86UE(#T@)#$["GT*)'!R;V=N86UE('Q\/2`D,#L*:68@*"1%
M3E9[4$%27U1%35!](&%N9"!I;F1E>"@D<')O9VYA;64L("1%3E9[4$%27U1%
M35!]*2`^/2`P*2!["B1P<F]G;F%M92`]('-U8G-T<B@D<')O9VYA;64L(')I
M;F1E>"@D<')O9VYA;64L("1#;VYF:6=[7V1E;&EM?2D@*R`Q*3L*?0II9B`H
M(21%3E9[4$%27U!23T=.04U%?2!O<B!I;F1E>"@D<')O9VYA;64L("1#;VYF
M:6=[7V1E;&EM?2D@/CT@,"D@>PII9B`H;W!E;B!M>2`D9F@L("<\)RP@)'!R
M;V=N86UE*2!["G)E='5R;B!I9B`M<R`D9F@["GT*:68@*"US("(D<')O9VYA
M;64D0V]N9FEG>U]E>&5](BD@>PHD<')O9VYA;64@+CT@)$-O;F9I9WM?97AE
M?3L*<F5T=7)N.PI]"GT*9F]R96%C:"!M>2`D9&ER("AS<&QI="`O7%$D0V]N
M9FEG>W!A=&A?<V5P?5Q%+RP@)$5.5GM0051(?2D@>PIN97AT(&EF(&5X:7-T
M<R`D14Y6>U!!4E]414U0?2!A;F0@)&1I<B!E<2`D14Y6>U!!4E]414U0?3L*
M)&1I<B`]?B!S+UQ1)$-O;F9I9WM?9&5L:6U]7$4D+R\["B@H)'!R;V=N86UE
M(#T@(B1D:7(D0V]N9FEG>U]D96QI;7TD<')O9VYA;64D0V]N9FEG>U]E>&5]
M(BDL(&QA<W0I"FEF("US("(D9&ER)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE
M)$-O;F9I9WM?97AE?2(["B@H)'!R;V=N86UE(#T@(B1D:7(D0V]N9FEG>U]D
M96QI;7TD<')O9VYA;64B*2P@;&%S="D*:68@+7,@(B1D:7(D0V]N9FEG>U]D
M96QI;7TD<')O9VYA;64B.PI]"GT*<W5B(%]F:7A?<')O9VYA;64@>PHD,"`]
M("1P<F]G;F%M92!\?#T@)$5.5GM005)?4%)/1TY!345].PII9B`H:6YD97@H
M)'!R;V=N86UE+"`D0V]N9FEG>U]D96QI;7TI(#P@,"D@>PHD<')O9VYA;64@
M/2`B+B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M92(["GT*;7D@)'!W9"`]("AD
M969I;F5D("9#=V0Z.F=E=&-W9"D@/R!#=V0Z.F=E=&-W9"@I"CH@*"AD969I
M;F5D("97:6XS,CHZ1V5T0W=D*2`_(%=I;C,R.CI'971#=V0H*2`Z(&!P=V1@
M*3L*8VAO;7`H)'!W9"D["B1P<F]G;F%M92`]?B!S+UXH/SU<+EPN/UQ1)$-O
M;F9I9WM?9&5L:6U]7$4I+R1P=V0D0V]N9FEG>U]D96QI;7TO.PHD14Y6>U!!
M4E]04D]'3D%-17T@/2`D<')O9VYA;64["GT*<W5B(%]P87)?:6YI=%]E;G8@
M>PII9B`H("1%3E9[4$%27TE.251)04Q)6D5$?2LK(#T](#$@*2!["G)E='5R
M;CL*?2!E;'-E('L*)$5.5GM005)?24Y)5$E!3$E:141](#T@,CL*?0IF;W(@
M*'%W*"!34$%73D5$(%1%35`@0TQ%04X@1$5"54<@0T%#2$4@4%)/1TY!344@
M*2`I('L*9&5L971E("1%3E9[)U!!4E\G+B1??3L*?0IF;W(@*'%W+R!435!$
M25(@5$5-4"!#3$5!3B!$14)51R`O*2!["B1%3E9[)U!!4E\G+B1??2`]("1%
M3E9[)U!!4E]'3$]"04Q?)RXD7WT@:68@97AI<W1S("1%3E9[)U!!4E]'3$]"
M04Q?)RXD7WT["GT*;7D@)'!A<E]C;&5A;B`](")?7T5.5E]005)?0TQ%04Y?
M7R`@("`@("`@("`@("`@("(["FEF("@D14Y6>U!!4E]414U0?2D@>PID96QE
M=&4@)$5.5GM005)?0TQ%04Y].PI]"F5L<VEF("@A97AI<W1S("1%3E9[4$%2
M7T=,3T)!3%]#3$5!3GTI('L*;7D@)'9A;'5E(#T@<W5B<W1R*"1P87)?8VQE
M86XL(#$R("L@;&5N9W1H*")#3$5!3B(I*3L*)$5.5GM005)?0TQ%04Y](#T@
M)#$@:68@)'9A;'5E(#U^("]>4$%27T-,14%./2A<4RLI+SL*?0I]"G-U8B!O
M=71S('L*<F5T=7)N(&EF("1Q=6EE=#L*:68@*"1L;V=F:"D@>PIP<FEN="`D
M;&]G9F@@(D!?7&XB.PI]"F5L<V4@>PIP<FEN="`B0%]<;B(["GT*?0IS=6(@
M:6YI=%]I;F,@>PIR97%U:7)E($-O;F9I9SL*<'5S:"!`24Y#+"!G<F5P(&1E
M9FEN960L(&UA<"`D0V]N9FEG.CI#;VYF:6=[)%]]+"!Q=R@*87)C:&QI8F5X
M<"!P<FEV;&EB97AP('-I=&5A<F-H97AP('-I=&5L:6)E>'`*=F5N9&]R87)C
M:&5X<"!V96YD;W)L:6)E>'`**3L*?0IP86-K86=E(&UA:6X["G)E<75I<F4@
M4$%2.PIU;G-H:69T($!)3D,L(%PF4$%2.CIF:6YD7W!A<CL*4$%2+3YI;7!O
M<G0H0'!A<E]A<F=S*3L*9&EE('%Q6W!A<BYP;#H@0V%N)W0@;W!E;B!P97)L
M('-C<FEP="`B)'!R;V=N86UE(CH@3F\@<W5C:"!F:6QE(&]R(&1I<F5C=&]R
M>5QN70IU;FQE<W,@+64@)'!R;V=N86UE.PID;R`D<')O9VYA;64["D-/4D4Z
M.F5X:70H)#$I(&EF("@D0"`]?B]>7U1+7T58251?7"@H7&0K*5PI+RD["F1I
M92`D0"!I9B`D0#L*?3L*)#HZ7U]%4E)/4B`]("1`(&EF("1`.PI]"D-/4D4Z
M.F5X:70H)#$I(&EF("@D.CI?7T524D]2(#U^+UY?5$M?15A)5%]<*"A<9"LI
M7"DO*3L*9&EE("0Z.E]?15)23U(@:68@)#HZ7U]%4E)/4CL*,3L*7U]%3D1?
M7PH`````````````7U]%3E9?4$%27T-,14%.7U\@("`@("`@("`@("`@("``
M`````````'!E<FQX<VDN8P````````````````````$;`SL```#D````&___
M?Y````#\__^`"````23__X&P```!F/__@P````'@__^#Z````A3__X78```"
M5/__B+@```*0__^)>````KS__XG0```"W/__BD````+\__^*2````Q#__XS8
M```#4/__C0@```-D__^.>````YC__Y$````#U/__D;@```0`__^2"```!"#_
M_Y-(```$5/__G7@```2@__^@D```!-C__Z%0```%2/__LZ````5T__^T*```
M!93__[9H```%W/__N&````%P__^Y(````4C__[G0```%#``````````0````
M``%Z4@`!?!\!&PT=`````"0````8__]^C````'@`1`X@1)P$5)`(2)\"3)$&
M`D@.`-#1W-\````@````0/__?MP```&D`$0.,$2<!%R?`I,&D@B1"I`,````
M```D````9/__M]````"L`$0.($2<!%R?`I$&2)`(`H`.`-#1W-\`````)```
M`(S__[;H````O`!$#B!$G`1<GP*1!DB0"`*0#@#0T=S?`````$0```"T__^`
M$````5``1`Y01)P$:)\"E@:5")0*DPR2#I$0D!("M`H.`-#1TM/4U=;<WT0+
M`F`*#@#0T=+3U-76W-]`"P```#````#\__^!&````.0`1`Y01)P$4)0&6),(
MD@J1#)`.GP("J`H.`-#1TM/4W-\+```````\```!,/__@<P```'L`$0.D`)$
MG`90D!9HGP*>!)<(E@J5#)0.DQ"2$I$4`EP*#@#0T=+3U-76U]S>WT0+````
M.````7#__X-\```"X`!$#F!$G`1HGP*4#)(0D1*0%)<&E@B5"I,.`P&,"@X`
MT-'2T]35UM?<WT0+````*````:S__X8@````O`!$#L`!1)P$4)`(3)$&GP("
M8`H.`-#1W-]$"P`````<```!V/__AK0```!4`$0.$$2<!%2?`G@.`-S?````
M`!P```'X__^&[````'``1`X@1)P$5)\"`E0.`-S?````$````AC__X<\````
M"``````````\```"+/__AS````*,`$0.H`I$G`90E`YHGP*3$)$4D!:>!)<(
ME@J5#)(2`J0*#@#0T=+3U-76U]S>WT0+````$````FS__XF`````,```````
M```P```"@/__B9P```%L`$0.($2<!%2?`I$&D`@"K`H.`-#1W-]`"P*("@X`
MT-'<WT`+````.````K3__XK8```"A`!$#H`!1)P$5),,2)`28)\"E@:5")0*
MD@Z1$`,!Q`H.`-#1TM/4U=;<WT`+````*````O#__XTD````M`!$#C!$G`14
MD0:0"$R?`GP*#@#0T=S?1`L````````<```#'/__C;````!,`$0.$$2<!%2?
M`G`.`-S?`````#````,\__^-X````4``1`Y01)P$4)$,6),(D@J?`I0&D`X#
M`00*#@#0T=+3U-S?"P````!(```#</__CNP```HP`$0.\/\!1)P&4)X$<`Z@
M@P*5#),0DA*0%I\"EPB6"I0.D10#`O@*#O#_`70.`-#1TM/4U=;7W-[?1`L`
M````-````[S__YC0```#%`!$#F!$G`10E`A<GP*1#I`0E0:3"I(,`P(`"@X`
MT-'2T]35W-]$"P`````P```#]/__F[````"X`$0.($2<!%R?`I$&D`@"<`H.
M`-#1W-]$"UC0T=S?2`X`````````.```!"C__[2\```"K`!$#F!$G`10D!!<
MGP*5!I0(DPJ2#)$.`P&\"@X`T-'2T]35W-\+````````````*```!&3__YP`
M```24`!$#O`"1)P$7)\"D0:0"`,2(`H.`-#1W-\+```````<```$D/__KB0`
M``"$`$0.$$2<!%2?`@)H#@#<WP```$0```2P__^NC````CP`1`Y09)P$E@:5
M")$0D!*?`I0*DPR2#@*T"@X`T-'2T]35UMS?1`L#`2@*#@#0T=+3U-76W-]`
M"P```#0```3X__^PA````>P`1`Y`8)P$E0:1#I`0GP*4"),*D@P#`:P*#@#0
MT=+3U-7<WT`+`````````/____\`````_____P`````````````````!FY@`
M`````````````````9F`````````````````_____P``````````````````
M5W@``````````````````````````````````````````(```````!-(``&9
M6``!FX@``9N0``&9<````````%.````28```31```@````!,8```2Z```)0H
M``&97``!F8```9E@``&99``!`````!RX```PN```)/@``"5(```=B```)$``
M`$;@``!':```2:@``"&X```=@```)H@``"!(```@&``!F:```#/0````````
M`````````````````````````````````````%-@``!34```4T````````!3
M,```4R```%,0``!3````4O```%+@``!2T```4L```%*P``!2H````````%*0
M````````4H```%)P``!28```4E```%)```!2,```4B```%(0``!2````````
M`%'P``!1X```4=```%'```!1L```4:```%&0````````48```%%P``!18```
M45```%%```!1,```42```%$0``!1``````````````!0\```4.```%#0``!0
MP```4+```%"@``!0D```4(```%!P``!08````````%!0``!00```4#```%`@
M``!0$```4````$_P````````3^```$_0``!/P````````````````$=#0SH@
M*$YE=$)31"!N8C,@,C`Q.3`S,3DI(#<N-"XP`$=#0SH@*$YE=$)31"!N8C0@
M,C`R,#`X,3`I(#<N-2XP```````2H``````````````````````````@````
M'0```!\``!+0D`,``/____@``````````````"`````=````'P``$TB0#P``
M____^```````````````,````!T````?```28```````````````````````
M```@````'0```!\``%.``````````````````````````"`````=````'P``
M3&"0`P``____^```````````````(````!T````?``!+H)`#``#____X````
M```````````@````'0```!\``!3PD'\``/____@``````````````%`````=
M````'P``%D"0'P``____^```````````````4````!T````?```7*-#_``#_
M___X``````````````$0````'0```!\``!D8D/\``/____@`````````````
M`&`````=````'P``&_B0`P``____^```````````````P````!T````?```<
MN)````#____X```````````````0````'0```!\``!T0D````/____@`````
M`````````"`````=````'P``'8```````````````````````````````!T`
M```?```=B-#_``#____X``````````````4@````'0```!\``"`8````````
M```````````````````````=````'P``($B0`P``____^```````````````
M(````!T````?```AN)!_``#____X``````````````"`````'0```!\``"1`
MD`,``/____@``````````````#`````=````'P``)/B0````____^```````
M````````$````!T````?```E2)`?``#____X``````````````!0````'0``
M`!\``":(T/\``/____@`````````````@:`````=````'P``,+B0/P``____
M^```````````````8````!T````?```ST)`#``#____X```````````````@
M````'0```!\``$T0D#\``/____@``````````````&`````=````'P``-)"0
M`P``____^``````````````!<````!T````?``!&X)````#____X````````
M```````0````'0```!\``$=HD'\``/____@``````````````%`````=````
M'P``2:B0/P``____^```````````````0````!T````?)$YE=$)31#H@8W)T
M,"Y3+'8@,2XT(#(P,3@O,3$O,C8@,3<Z,S<Z-#4@:F]E<F<@17AP("0`)$YE
M=$)31#H@8W)T,"UC;VUM;VXN8RQV(#$N,C,@,C`Q."\Q,B\R."`R,#HQ,CHS
M-2!C:')I<W1O<R!%>'`@)``D3F5T0E-$.B!C<G1I+E,L=B`Q+C,@,C`Q-2\P
M-2\P,2`R,3HS-3HU-B!M871T($5X<"`D`"1.971"4T0Z(&-R=&)E9VEN+F,L
M=B`Q+C$W(#(P,3@O,3(O,C@@,3@Z,3<Z,3$@8VAR:7-T;W,@17AP("0`)$YE
M=$)31#H@8W)T96YD+E,L=B`Q+C0@,C`Q-R\P-R\Q."`Q-#HS-#HQ.2!J;V5R
M9R!%>'`@)``D3F5T0E-$.B!C<G1N+E,L=B`Q+C(@,C`Q,R\P-B\S,"`P.#HP
M,#HS-"!M871T($5X<"`D`$$````/9VYU``$````'!`,`+G-H<W1R=&%B`"YI
M;G1E<G``+FYO=&4N;F5T8G-D+FED96YT`"YN;W1E+FYE=&)S9"YP87@`+DU)
M4%,N86)I9FQA9W,`+G)E9VEN9F\`+F1Y;F%M:6,`+FAA<V@`+F1Y;G-Y;0`N
M9'EN<W1R`"YR96PN9'EN`"YI;FET`"YT97AT`"Y-25!3+G-T=6)S`"YF:6YI
M`"YR;V1A=&$`+F5H7V9R86UE7VAD<@`N96A?9G)A;64`+F-T;W)S`"YD=&]R
M<P`N:F-R`"YD871A`"YR;&1?;6%P`"YG;W0`+G-B<W,`+F)S<P`N8V]M;65N
M=``N<&1R`"YG;G4N871T<FEB=71E<P``````````````````````````````
M````````````````````````````"P````$````"```!=````70````7````
M```````````!`````````!,````'`````@```8P```&,````&```````````
M````!``````````F````!P````(```&D```!I````!0```````````````0`
M````````-W```"H````"```!N````;@````8```````````````(````&```
M`$9P```&`````@```=````'0````&```````````````"````!@```!/````
M!@````(```'H```!Z````0@````)``````````0````(````6`````4````"
M```"\````O````,H````"``````````$````!````%X````+`````@``!A@`
M``88```&<`````D````"````!````!````!F`````P````(```R(```,B```
M!-````````````````$`````````;@````D````"```16```$5@````P````
M"``````````$````"````'<````!````!@``$F```!)@````.```````````
M````!`````````!]`````0````8``!*@```2H```/2```````````````!``
M````````@P````$````&``!/P```3\````/````````````````$````````
M`(\````!````!@``4X```%.`````.```````````````!`````````"5````
M`0````(``%/```!3P```/X```````````````!``````````G0````$````"
M``"30```DT````#D```````````````$`````````*L````!`````@``E"@`
M`)0H```%,```````````````"`````````"U`````0````,``9E8``"96```
M``@```````````````0`````````O`````$````#``&98```F6`````(````
M```````````$`````````,,````!`````P`!F6@``)EH````!```````````
M````"`````````#(`````0````,``9EP``"9<````$```````````````!``
M````````S@````$````#``&9L```F;`````$```````````````$````````
M`-<````!$````P`!F<```)G````!R```````````````$`````0```#<````
M`1````,``9N(``";B`````0```````````````@`````````X@````@````#
M``&;D```FXP```10```````````````0`````````.<````!````,```````
M`)N,````0@```````````````0````$```#P`````0````````````";T```
M`\````````````````0`````````'P````$`````````````GY````%7````
M```````````!`````````/5O___U`````````````*#G````$```````````
M`````0`````````!`````P````````````"@]P```04```````````````$`
#````
